from .config import Config, ctypes
from .config import auto_encode

# INT64 __stdcall HCSC_SetPath(char* rootPath);
def HD主板机_设置路径(根目录: str) -> int:
    """
    设置HD主板机根目录路径
    
    Args:
        根目录: 根目录（hdscrcpy.exe和adb.exe所在目录）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSC_SetPath = hd.HCSC_SetPath
    HCSC_SetPath.restype = ctypes.c_int64
    HCSC_SetPath.argtypes = [ctypes.c_char_p]
    
    ret = HCSC_SetPath(auto_encode(根目录))
    return ret

# INT64 __stdcall HCSC_ResetAdb(char* ipInfo);
def HD主板机_重置ADB服务(IP端口信息: str = None) -> int:
    """
    重置ADB服务并可以添加连接IP
    
    Args:
        IP端口信息: IP端口信息（多个IP信息用"|"隔开，IP和端口用":"隔开，如："127.0.0.1:123|127.0.0.2:789|"，可以为None）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCSC_ResetAdb = hd.HCSC_ResetAdb
    HCSC_ResetAdb.restype = ctypes.c_int64
    HCSC_ResetAdb.argtypes = [ctypes.c_char_p]
    
    if IP端口信息:
        ret = HCSC_ResetAdb(auto_encode(IP端口信息))
    else:
        ret = HCSC_ResetAdb(None)
    return ret

# INT64 __stdcall HCSC_QueryDevices();
def HD主板机_查询设备() -> int:
    """
    查询当前所有可用的设备
    
    Returns:
        int: 返回值代码（查看HD返回值表）
            成功返回JSON字符串信息：设备1名字|设备2名字|设备3名字|（以"|"分割）
            失败返回JSON字符串信息：连接失败信息
    """
    hd = Config.get_hd()
    
    HCSC_QueryDevices = hd.HCSC_QueryDevices
    HCSC_QueryDevices.restype = ctypes.c_int64
    HCSC_QueryDevices.argtypes = []
    
    ret = HCSC_QueryDevices()
    return ret

# INT64 __stdcall HCSC_ConnectDevices(int winIndex, char* devicesName, char* cmdLparam, int type, int w, int h, int timeOut);
def HD主板机_连接设备(窗口序号: int, 设备号: str, 命令额外参数: str = None, 设备号类型: int = 1, 宽度: int = 1280, 高度: int = 720, 超时连接毫秒: int = 10000) -> int:
    """
    连接设备并通讯窗口序号（需要先初始化中控和登录！HCHD_Login HCEnv_Init/HCEnv_InitEx）
    
    Args:
        窗口序号: 窗口序号
        设备号: 设备号
        命令额外参数: 命令额外参数（参考投屏器命令行指令hdscrcpy命令行解析）
        设备号类型: 设备号类型（1: -s 模拟器描述, 2: -d USB设备号, 3: -e Ip:port）
        宽度: 宽度
        高度: 高度
        超时连接毫秒: 超时连接毫秒（一般10秒也就是10000毫秒）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
            成功返回打开的窗口PID
    """
    hd = Config.get_hd()
    
    HCSC_ConnectDevices = hd.HCSC_ConnectDevices
    HCSC_ConnectDevices.restype = ctypes.c_int64
    HCSC_ConnectDevices.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32]
    
    if 命令额外参数:
        cmd_param = auto_encode(命令额外参数)
    else:
        cmd_param = None
    
    ret = HCSC_ConnectDevices(
        ctypes.c_int32(窗口序号),
        auto_encode(设备号),
        cmd_param,
        ctypes.c_int32(设备号类型),
        ctypes.c_int32(宽度),
        ctypes.c_int32(高度),
        ctypes.c_int32(超时连接毫秒)
    )
    return ret


from .config import Config, ctypes
from .config import auto_encode

# __int64 __stdcall HC_OpenBS(__int32 窗口序号, __int32 minIndex = 0, __int32 maxIndex = 0, BOOL 是否主线程调用 = FALSE);
def HD黑屏_打开(窗口序号: int, minIndex: int = 0, maxIndex: int = 0, 是否主线程调用: bool = False) -> int:
    """
    打开黑屏
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        minIndex: 最小模型序号 (默认0)
        maxIndex: 最大模型序号 (默认0)
        是否主线程调用: 是否需要主线程来调用这个CALL (默认False)
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    func = hd.HC_OpenBS
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int, ctypes.c_int, ctypes.c_bool]

    return func(窗口序号, minIndex, maxIndex, 是否主线程调用)

# __int64 __stdcall HC_SetBs(__int32 窗口序号, __int32 minIndex = 0, __int32 maxIndex = 0);
def HD黑屏_设置模型范围(窗口序号: int, minIndex: int = 0, maxIndex: int = 0) -> int:
    """
    设置模型序号的过滤范围
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        minIndex: 最小模型序号 (默认0)
        maxIndex: 最大模型序号 (默认0)
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    func = hd.HC_SetBs
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int, ctypes.c_int]

    return func(窗口序号, minIndex, maxIndex)

# __int64 __stdcall HC_CloseBS(__int32 窗口序号, BOOL 是否主线程调用 = FALSE);
def HD黑屏_关闭(窗口序号: int, 是否主线程调用: bool = False) -> int:
    """
    关闭黑屏
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        是否主线程调用: 是否需要主线程来调用这个CALL (默认False)
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()

    func = hd.HC_CloseBS
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_bool]

    return func(窗口序号, 是否主线程调用)


from .config import Config, ctypes
from .config import auto_encode

# INT64 __stdcall HCM_FindCode(int windowsIndex, char* pattern, int offset, int times, int type, char* moduleName);
def HD内存_特征码(窗口序号: int, 特征码字符串: str, 偏移: int, 次数: int, 地址类型: int = 1, 模块名字: str = None) -> int:
    """
    特征码查找
    
    Args:
        窗口序号: 窗口序号（从1开始）
        特征码字符串: 特征码字符串（支持??）
        偏移: 正负偏移量
        次数: 查找次数（从1开始）
        地址类型: 地址类型（1=地址，2=基地址，3=CALL地址，4=地址中的值），默认1
        模块名字: 指定搜索的模块名（默认主模块）
    
    Returns:
        int: 查找到的内存地址/值
    """
    hd = Config.get_hd()
    
    HCM_FindCode = hd.HCM_FindCode
    HCM_FindCode.restype = ctypes.c_int64
    HCM_FindCode.argtypes = [ctypes.c_int, ctypes.c_char_p, ctypes.c_int, ctypes.c_int, ctypes.c_int, ctypes.c_char_p]
    
    ret = HCM_FindCode(
        ctypes.c_int(窗口序号),
        auto_encode(特征码字符串),
        ctypes.c_int(偏移),
        ctypes.c_int(次数),
        ctypes.c_int(地址类型),
        auto_encode(模块名字) if 模块名字 else None
    )
    return ret

# INT64 __stdcall HCM_FindCodeEx(int windowsIndex, INT64 startAddr, INT64 scanSize, char* pattern, int offset, int times, int type);
def HD内存_特征码Ex(窗口序号: int, 开始地址: int, 扫描范围大小: int, 特征码字符串: str, 偏移: int, 次数: int, 地址类型: int = 1) -> int:
    """
    特征码查找（扩展版本）
    
    Args:
        窗口序号: 窗口序号（从1开始）
        开始地址: 扫描起始地址
        扫描范围大小: 扫描内存范围大小
        特征码字符串: 特征码字符串（支持??）
        偏移: 正负偏移量
        次数: 查找次数（从1开始）
        地址类型: 地址类型（1=地址，2=基地址，3=CALL地址，4=地址中的值），默认1
    
    Returns:
        int: 查找到的内存地址/值
    """
    hd = Config.get_hd()
    
    HCM_FindCodeEx = hd.HCM_FindCodeEx
    HCM_FindCodeEx.restype = ctypes.c_int64
    HCM_FindCodeEx.argtypes = [ctypes.c_int, ctypes.c_int64, ctypes.c_int64, ctypes.c_char_p, ctypes.c_int, ctypes.c_int, ctypes.c_int]
    
    ret = HCM_FindCodeEx(
        ctypes.c_int(窗口序号),
        ctypes.c_int64(开始地址),
        ctypes.c_int64(扫描范围大小),
        auto_encode(特征码字符串),
        ctypes.c_int(偏移),
        ctypes.c_int(次数),
        ctypes.c_int(地址类型)
    )
    return ret

# INT64 __stdcall HCM_Read(int windowsIndex, char* expression, int readSize, char* moduleName, BOOL isMainThread);
def HD内存_读表达式(窗口序号: int, 表达式字符串: str, 读取大小: int, 模块名字: str = None, 是否主线程调用: bool = False) -> int:
    """
    读整数型数据
    
    Args:
        窗口序号: 窗口序号（从1开始）
        表达式字符串: 偏移表达式（例如"0x123456]+0x56]-0x44]"）
        读取大小: 读取字节数（1/2/4/8）
        模块名字: 指定模块（默认主模块）
        是否主线程调用: 是否强制主线程调用，默认False
    
    Returns:
        int: 读取的数值
    """
    hd = Config.get_hd()
    
    HCM_Read = hd.HCM_Read
    HCM_Read.restype = ctypes.c_int64
    HCM_Read.argtypes = [ctypes.c_int, ctypes.c_char_p, ctypes.c_int, ctypes.c_char_p, ctypes.c_bool]
    
    ret = HCM_Read(
        ctypes.c_int(窗口序号),
        auto_encode(表达式字符串),
        ctypes.c_int(读取大小),
        auto_encode(模块名字) if 模块名字 else None,
        ctypes.c_bool(是否主线程调用)
    )
    return ret

# INT64 __stdcall HCM_ReadAddr(int windowsIndex, INT64 addr, int readSize, BOOL isMainThread);
def HD内存_读地址(窗口序号: int, 内存地址: int, 读取大小: int, 是否主线程调用: bool = False) -> int:
    """
    直接读取内存地址数据
    
    Args:
        窗口序号: 窗口序号（从1开始）
        内存地址: 目标内存地址
        读取大小: 读取字节数（1/2/4/8）
        是否主线程调用: 是否强制主线程调用，默认False
    
    Returns:
        int: 读取的数值
    """
    hd = Config.get_hd()
    
    HCM_ReadAddr = hd.HCM_ReadAddr
    HCM_ReadAddr.restype = ctypes.c_int64
    HCM_ReadAddr.argtypes = [ctypes.c_int, ctypes.c_int64, ctypes.c_int, ctypes.c_bool]
    
    ret = HCM_ReadAddr(
        ctypes.c_int(窗口序号),
        ctypes.c_int64(内存地址),
        ctypes.c_int(读取大小),
        ctypes.c_bool(是否主线程调用)
    )
    return ret

# INT64 __stdcall HCM_Write(int windowsIndex, char* expression, INT64 value, int writeSize, char* moduleName, BOOL isMainThread);
def HD内存_写表达式(窗口序号: int, 表达式字符串: str, 数值: int, 写入大小: int, 模块名字: str = None, 是否主线程调用: bool = False) -> int:
    """
    写入整数数据到表达式地址
    
    Args:
        窗口序号: 窗口序号（从1开始）
        表达式字符串: 偏移表达式
        数值: 要写入的数值
        写入大小: 写入字节数（1~8）
        模块名字: 指定模块（默认主模块）
        是否主线程调用: 是否强制主线程调用
    
    Returns:
        int: 操作结果代码
    """
    hd = Config.get_hd()
    
    HCM_Write = hd.HCM_Write
    HCM_Write.restype = ctypes.c_int64
    HCM_Write.argtypes = [ctypes.c_int, ctypes.c_char_p, ctypes.c_int64, ctypes.c_int, ctypes.c_char_p, ctypes.c_bool]
    
    ret = HCM_Write(
        ctypes.c_int(窗口序号),
        auto_encode(表达式字符串),
        ctypes.c_int64(数值),
        ctypes.c_int(写入大小),
        auto_encode(模块名字) if 模块名字 else None,
        ctypes.c_bool(是否主线程调用)
    )
    return ret

# INT64 __stdcall HCM_WriteAddr(int windowsIndex, INT64 addr, INT64 value, int writeSize, BOOL isMainThread);
def HD内存_写地址(窗口序号: int, 内存地址: int, 数值: int, 写入大小: int, 是否主线程调用: bool = False) -> int:
    """
    直接写入数据到内存地址
    
    Args:
        窗口序号: 窗口序号（从1开始）
        内存地址: 目标内存地址
        数值: 要写入的数值
        写入大小: 写入字节数（1~8）
        是否主线程调用: 是否强制主线程调用
    
    Returns:
        int: 操作结果代码
    """
    hd = Config.get_hd()
    
    HCM_WriteAddr = hd.HCM_WriteAddr
    HCM_WriteAddr.restype = ctypes.c_int64
    HCM_WriteAddr.argtypes = [ctypes.c_int, ctypes.c_int64, ctypes.c_int64, ctypes.c_int, ctypes.c_bool]
    
    ret = HCM_WriteAddr(
        ctypes.c_int(窗口序号),
        ctypes.c_int64(内存地址),
        ctypes.c_int64(数值),
        ctypes.c_int(写入大小),
        ctypes.c_bool(是否主线程调用)
    )
    return ret

# INT64 __stdcall HCM_ReadData(int windowsIndex, char* expression, BYTE* byteBuffer, int bufferSize, int readSize, char* moduleName, BOOL isMainThread);
def HD内存_读表达式字节流(窗口序号: int, 表达式字符串: str, 字节缓冲区, 缓冲区大小: int, 读取大小: int, 模块名字: str = None, 是否主线程调用: bool = False) -> int:
    """
    读取表达式地址的字节流数据
    
    Args:
        窗口序号: 窗口序号（从1开始）
        表达式字符串: 偏移表达式
        字节缓冲区: 由外部创建的ctypes缓冲区
        缓冲区大小: 缓冲区大小
        读取大小: 要读取的字节数
        模块名字: 指定模块（默认主模块）
        是否主线程调用: 是否强制主线程调用
    
    Returns:
        int: 实际读取的字节数
    """
    hd = Config.get_hd()
    
    HCM_ReadData = hd.HCM_ReadData
    HCM_ReadData.restype = ctypes.c_int64
    HCM_ReadData.argtypes = [ctypes.c_int, ctypes.c_char_p, ctypes.POINTER(ctypes.c_ubyte), ctypes.c_int, ctypes.c_int, ctypes.c_char_p, ctypes.c_bool]
    
    ret = HCM_ReadData(
        ctypes.c_int(窗口序号),
        auto_encode(表达式字符串),
        字节缓冲区,
        ctypes.c_int(缓冲区大小),
        ctypes.c_int(读取大小),
        auto_encode(模块名字) if 模块名字 else None,
        ctypes.c_bool(是否主线程调用)
    )
    return ret

# INT64 __stdcall HCM_ReadFloat(int windowsIndex, char* expression, int readSize, char* moduleName, BOOL isMainThread);
def HD内存_读表达式浮点数(窗口序号: int, 表达式字符串: str, 读取大小: int, 模块名字: str = None, 是否主线程调用: bool = False) -> int:
    """
    读取表达式地址的浮点数
    
    Args:
        窗口序号: 窗口序号（从1开始）
        表达式字符串: 偏移表达式
        读取大小: 浮点数大小（4=单精度，8=双精度）
        模块名字: 指定模块（默认主模块）
        是否主线程调用: 是否强制主线程调用
    
    Returns:
        int: 浮点数的整数形式
    """
    hd = Config.get_hd()
    
    HCM_ReadFloat = hd.HCM_ReadFloat
    HCM_ReadFloat.restype = ctypes.c_int64
    HCM_ReadFloat.argtypes = [ctypes.c_int, ctypes.c_char_p, ctypes.c_int, ctypes.c_char_p, ctypes.c_bool]
    
    ret = HCM_ReadFloat(
        ctypes.c_int(窗口序号),
        auto_encode(表达式字符串),
        ctypes.c_int(读取大小),
        auto_encode(模块名字) if 模块名字 else None,
        ctypes.c_bool(是否主线程调用)
    )
    return ret

# INT64 __stdcall HCM_ReadDataAddr(int windowsIndex, INT64 addr, int bufferSize, int readSize, BOOL isMainThread);
def HD内存_读地址字节流(窗口序号: int, 内存地址: int, 缓冲区大小: int, 读取大小: int, 是否主线程调用: bool = False) -> int:
    """
    读取内存地址的字节流数据
    
    Args:
        窗口序号: 窗口序号（从1开始）
        内存地址: 目标内存地址
        缓冲区大小: 缓冲区大小
        读取大小: 要读取的字节数
        是否主线程调用: 是否强制主线程调用
    
    Returns:
        int: 实际读取的字节数
    """
    hd = Config.get_hd()
    
    HCM_ReadDataAddr = hd.HCM_ReadDataAddr
    HCM_ReadDataAddr.restype = ctypes.c_int64
    HCM_ReadDataAddr.argtypes = [ctypes.c_int, ctypes.c_int64, ctypes.c_int, ctypes.c_int, ctypes.c_bool]
    
    ret = HCM_ReadDataAddr(
        ctypes.c_int(窗口序号),
        ctypes.c_int64(内存地址),
        ctypes.c_int(缓冲区大小),
        ctypes.c_int(读取大小),
        ctypes.c_bool(是否主线程调用)
    )
    return ret

# INT64 __stdcall HCM_ReadFloatAddr(int windowsIndex, INT64 addr, int readSize, BOOL isMainThread);
def HD内存_读地址浮点数(窗口序号: int, 内存地址: int, 读取大小: int, 是否主线程调用: bool = False) -> int:
    """
    读取内存地址的浮点数
    
    Args:
        窗口序号: 窗口序号（从1开始）
        内存地址: 目标内存地址
        读取大小: 浮点数大小（4=单精度，8=双精度）
        是否主线程调用: 是否强制主线程调用
    
    Returns:
        int: 浮点数的整数形式
    """
    hd = Config.get_hd()
    
    HCM_ReadFloatAddr = hd.HCM_ReadFloatAddr
    HCM_ReadFloatAddr.restype = ctypes.c_int64
    HCM_ReadFloatAddr.argtypes = [ctypes.c_int, ctypes.c_int64, ctypes.c_int, ctypes.c_bool]
    
    ret = HCM_ReadFloatAddr(
        ctypes.c_int(窗口序号),
        ctypes.c_int64(内存地址),
        ctypes.c_int(读取大小),
        ctypes.c_bool(是否主线程调用)
    )
    return ret

# INT64 __stdcall HCM_WriteData(int windowsIndex, char* expression, BYTE* byteBuffer, int writeSize, char* moduleName, BOOL isMainThread);
def HD内存_写表达式字节流(窗口序号: int, 表达式字符串: str, 字节数据: bytes, 写入大小: int, 模块名字: str = None, 是否主线程调用: bool = False) -> int:
    """
    写入字节流数据到表达式地址
    
    Args:
        窗口序号: 窗口序号（从1开始）
        表达式字符串: 偏移表达式
        字节数据: 要写入的字节数据 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
        写入大小: 写入字节数
        模块名字: 指定模块（默认主模块）
        是否主线程调用: 是否强制主线程调用
    
    Returns:
        int: 实际写入的字节数
    """
    hd = Config.get_hd()
    
    HCM_WriteData = hd.HCM_WriteData
    HCM_WriteData.restype = ctypes.c_int64
    HCM_WriteData.argtypes = [ctypes.c_int, ctypes.c_char_p, ctypes.POINTER(ctypes.c_ubyte), ctypes.c_int, ctypes.c_char_p, ctypes.c_bool]
    
    buffer_type = ctypes.c_ubyte * len(字节数据)
    buffer_data = buffer_type(*字节数据)
    
    ret = HCM_WriteData(
        ctypes.c_int(窗口序号),
        auto_encode(表达式字符串),
        buffer_data,
        ctypes.c_int(写入大小),
        auto_encode(模块名字) if 模块名字 else None,
        ctypes.c_bool(是否主线程调用)
    )
    return ret

# INT64 __stdcall HCM_WriteFloat(int windowsIndex, char* expression, float value, char* moduleName, BOOL isMainThread);
def HD内存_写表达式单浮点(窗口序号: int, 表达式字符串: str, 浮点值: float, 模块名字: str = None, 是否主线程调用: bool = False) -> int:
    """
    写入单精度浮点数到表达式地址
    
    Args:
        窗口序号: 窗口序号（从1开始）
        表达式字符串: 偏移表达式
        浮点值: 要写入的单精度浮点数
        模块名字: 指定模块（默认主模块）
        是否主线程调用: 是否强制主线程调用
    
    Returns:
        int: 操作结果代码
    """
    hd = Config.get_hd()
    
    HCM_WriteFloat = hd.HCM_WriteFloat
    HCM_WriteFloat.restype = ctypes.c_int64
    HCM_WriteFloat.argtypes = [ctypes.c_int, ctypes.c_char_p, ctypes.c_float, ctypes.c_char_p, ctypes.c_bool]
    
    ret = HCM_WriteFloat(
        ctypes.c_int(窗口序号),
        auto_encode(表达式字符串),
        ctypes.c_float(浮点值),
        auto_encode(模块名字) if 模块名字 else None,
        ctypes.c_bool(是否主线程调用)
    )
    return ret

# INT64 __stdcall HCM_WriteDouble(int windowsIndex, char* expression, double value, char* moduleName, BOOL isMainThread);
def HD内存_写表达式双浮点(窗口序号: int, 表达式字符串: str, 双浮点值: float, 模块名字: str = None, 是否主线程调用: bool = False) -> int:
    """
    写入双精度浮点数到表达式地址
    
    Args:
        窗口序号: 窗口序号（从1开始）
        表达式字符串: 偏移表达式
        双浮点值: 要写入的双精度浮点数
        模块名字: 指定模块（默认主模块）
        是否主线程调用: 是否强制主线程调用
    
    Returns:
        int: 操作结果代码
    """
    hd = Config.get_hd()
    
    HCM_WriteDouble = hd.HCM_WriteDouble
    HCM_WriteDouble.restype = ctypes.c_int64
    HCM_WriteDouble.argtypes = [ctypes.c_int, ctypes.c_char_p, ctypes.c_double, ctypes.c_char_p, ctypes.c_bool]
    
    ret = HCM_WriteDouble(
        ctypes.c_int(窗口序号),
        auto_encode(表达式字符串),
        ctypes.c_double(双浮点值),
        auto_encode(模块名字) if 模块名字 else None,
        ctypes.c_bool(是否主线程调用)
    )
    return ret

# INT64 __stdcall HCM_WriteDataAddr(int windowsIndex, INT64 addr, BYTE* byteBuffer, int writeSize, BOOL isMainThread);
def HD内存_写地址字节流(窗口序号: int, 内存地址: int, 字节数据: bytes, 写入大小: int, 是否主线程调用: bool = False) -> int:
    """
    写入字节流数据到内存地址
    
    Args:
        窗口序号: 窗口序号（从1开始）
        内存地址: 目标内存地址
        字节数据: 要写入的字节数据 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
        写入大小: 写入字节数
        是否主线程调用: 是否强制主线程调用
    
    Returns:
        int: 实际写入的字节数
    """
    hd = Config.get_hd()
    
    HCM_WriteDataAddr = hd.HCM_WriteDataAddr
    HCM_WriteDataAddr.restype = ctypes.c_int64
    HCM_WriteDataAddr.argtypes = [ctypes.c_int, ctypes.c_int64, ctypes.POINTER(ctypes.c_ubyte), ctypes.c_int, ctypes.c_bool]
    
    buffer_type = ctypes.c_ubyte * len(字节数据)
    buffer_data = buffer_type(*字节数据)
    
    ret = HCM_WriteDataAddr(
        ctypes.c_int(窗口序号),
        ctypes.c_int64(内存地址),
        buffer_data,
        ctypes.c_int(写入大小),
        ctypes.c_bool(是否主线程调用)
    )
    return ret

# INT64 __stdcall HCM_WriteFloatAddr(int windowsIndex, INT64 addr, float value, BOOL isMainThread);
def HD内存_写地址单浮点(窗口序号: int, 内存地址: int, 浮点值: float, 是否主线程调用: bool = False) -> int:
    """
    写入单精度浮点数到内存地址
    
    Args:
        窗口序号: 窗口序号（从1开始）
        内存地址: 目标内存地址
        浮点值: 要写入的单精度浮点数
        是否主线程调用: 是否强制主线程调用
    
    Returns:
        int: 操作结果代码
    """
    hd = Config.get_hd()
    
    HCM_WriteFloatAddr = hd.HCM_WriteFloatAddr
    HCM_WriteFloatAddr.restype = ctypes.c_int64
    HCM_WriteFloatAddr.argtypes = [ctypes.c_int, ctypes.c_int64, ctypes.c_float, ctypes.c_bool]
    
    ret = HCM_WriteFloatAddr(
        ctypes.c_int(窗口序号),
        ctypes.c_int64(内存地址),
        ctypes.c_float(浮点值),
        ctypes.c_bool(是否主线程调用)
    )
    return ret

# INT64 __stdcall HCM_WriteDoubleAddr(int windowsIndex, INT64 addr, double value, BOOL isMainThread);
def HD内存_写地址双浮点(窗口序号: int, 内存地址: int, 双浮点值: float, 是否主线程调用: bool = False) -> int:
    """
    写入双精度浮点数到内存地址
    
    Args:
        窗口序号: 窗口序号（从1开始）
        内存地址: 目标内存地址
        双浮点值: 要写入的双精度浮点数
        是否主线程调用: 是否强制主线程调用
    
    Returns:
        int: 操作结果代码
    """
    hd = Config.get_hd()
    
    HCM_WriteDoubleAddr = hd.HCM_WriteDoubleAddr
    HCM_WriteDoubleAddr.restype = ctypes.c_int64
    HCM_WriteDoubleAddr.argtypes = [ctypes.c_int, ctypes.c_int64, ctypes.c_double, ctypes.c_bool]
    
    ret = HCM_WriteDoubleAddr(
        ctypes.c_int(窗口序号),
        ctypes.c_int64(内存地址),
        ctypes.c_double(双浮点值),
        ctypes.c_bool(是否主线程调用)
    )
    return ret

# INT64 __stdcall HCM_GetModuleAddress(int windowsIndex, char* moduleName, BOOL isMainThread);
def HD内存_获取模块地址(窗口序号: int, 模块名字: str = None, 是否主线程调用: bool = False) -> int:
    """
    获取模块基地址
    
    Args:
        窗口序号: 窗口序号（从1开始）
        模块名字: 模块名字（默认主模块）
        是否主线程调用: 是否强制主线程调用
    
    Returns:
        int: 模块基地址
    """
    hd = Config.get_hd()
    
    HCM_GetModuleAddress = hd.HCM_GetModuleAddress
    HCM_GetModuleAddress.restype = ctypes.c_int64
    HCM_GetModuleAddress.argtypes = [ctypes.c_int, ctypes.c_char_p, ctypes.c_bool]
    
    ret = HCM_GetModuleAddress(
        ctypes.c_int(窗口序号),
        auto_encode(模块名字) if 模块名字 else None,
        ctypes.c_bool(是否主线程调用)
    )
    return ret

# INT64 __stdcall HCM_GetProcAddress(int windowsIndex, char* moduleName, char* procName, BOOL isMainThread);
def HD内存_获取模块接口地址(窗口序号: int, 模块名字: str, 接口名字: str, 是否主线程调用: bool = False) -> int:
    """
    获取模块导出函数地址
    
    Args:
        窗口序号: 窗口序号（从1开始）
        模块名字: 模块名字
        接口名字: 导出函数名字
        是否主线程调用: 是否强制主线程调用
    
    Returns:
        int: 函数地址
    """
    hd = Config.get_hd()
    
    HCM_GetProcAddress = hd.HCM_GetProcAddress
    HCM_GetProcAddress.restype = ctypes.c_int64
    HCM_GetProcAddress.argtypes = [ctypes.c_int, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_bool]
    
    ret = HCM_GetProcAddress(
        ctypes.c_int(窗口序号),
        auto_encode(模块名字),
        auto_encode(接口名字),
        ctypes.c_bool(是否主线程调用)
    )
    return ret

# INT64 __stdcall HCM_IsValidPtr(int windowsIndex, INT64 addr, int size, BOOL isMainThread);
def HD内存_地址是否可读(窗口序号: int, 内存地址: int, 地址大小: int = 8, 是否主线程调用: bool = False) -> int:
    """
    检查内存地址是否可读
    
    Args:
        窗口序号: 窗口序号（从1开始）
        内存地址: 要检查的内存地址
        地址大小: 地址大小，默认8
        是否主线程调用: 是否强制主线程调用
    
    Returns:
        int: 是否可读（1=可读，0=不可读）
    """
    hd = Config.get_hd()
    
    HCM_IsValidPtr = hd.HCM_IsValidPtr
    HCM_IsValidPtr.restype = ctypes.c_int64
    HCM_IsValidPtr.argtypes = [ctypes.c_int, ctypes.c_int64, ctypes.c_int, ctypes.c_bool]
    
    ret = HCM_IsValidPtr(
        ctypes.c_int(窗口序号),
        ctypes.c_int64(内存地址),
        ctypes.c_int(地址大小),
        ctypes.c_bool(是否主线程调用)
    )
    return ret

def HD内存_浮点取整数形式值(浮点值: float) -> int:
    """
    将浮点数转换为整数形式（用于内存操作）
    
    Args:
        浮点值: 要转换的浮点数
    
    Returns:
        int: 整数形式的值
    """
    import struct
    return struct.unpack('I', struct.pack('f', 浮点值))[0]

# INT64 __stdcall HCM_ExecAssemblyX86(int windowsIndex, INT64 targetAddr, char* assembly, BOOL releaseAddr, BOOL isMainThread);
def HD内存_执行汇编X86(窗口序号: int, 目标进程地址: int = 0, 汇编文本: str = None, 是否释放地址: bool = False, 是否主线程调用: bool = False) -> int:
    """
    执行X86汇编代码
    
    Args:
        窗口序号: 窗口序号（从1开始）
        目标进程地址: 目标进程地址，0表示自动分配
        汇编文本: 汇编代码文本
        是否释放地址: 执行完是否释放地址
        是否主线程调用: 是否强制主线程调用
    
    Returns:
        int: 执行结果或分配的地址
    """
    hd = Config.get_hd()
    
    HCM_ExecAssemblyX86 = hd.HCM_ExecAssemblyX86
    HCM_ExecAssemblyX86.restype = ctypes.c_int64
    HCM_ExecAssemblyX86.argtypes = [ctypes.c_int, ctypes.c_int64, ctypes.c_char_p, ctypes.c_bool, ctypes.c_bool]
    
    ret = HCM_ExecAssemblyX86(
        ctypes.c_int(窗口序号),
        ctypes.c_int64(目标进程地址),
        auto_encode(汇编文本) if 汇编文本 else None,
        ctypes.c_bool(是否释放地址),
        ctypes.c_bool(是否主线程调用)
    )
    return ret

# INT64 __stdcall HCM_ExecAssemblyX64(int windowsIndex, INT64 targetAddr, char* assembly, BOOL releaseAddr, BOOL isMainThread);
def HD内存_执行汇编X64(窗口序号: int, 目标进程地址: int = 0, 汇编文本: str = None, 是否释放地址: bool = False, 是否主线程调用: bool = False) -> int:
    """
    执行X64汇编代码
    
    Args:
        窗口序号: 窗口序号（从1开始）
        目标进程地址: 目标进程地址，0表示自动分配
        汇编文本: 汇编代码文本
        是否释放地址: 执行完是否释放地址
        是否主线程调用: 是否强制主线程调用
    
    Returns:
        int: 执行结果或分配的地址
    """
    hd = Config.get_hd()
    
    HCM_ExecAssemblyX64 = hd.HCM_ExecAssemblyX64
    HCM_ExecAssemblyX64.restype = ctypes.c_int64
    HCM_ExecAssemblyX64.argtypes = [ctypes.c_int, ctypes.c_int64, ctypes.c_char_p, ctypes.c_bool, ctypes.c_bool]
    
    ret = HCM_ExecAssemblyX64(
        ctypes.c_int(窗口序号),
        ctypes.c_int64(目标进程地址),
        auto_encode(汇编文本) if 汇编文本 else None,
        ctypes.c_bool(是否释放地址),
        ctypes.c_bool(是否主线程调用)
    )
    return ret

def HD内存_浮点整数转浮点数(整数值: int) -> float:
    """
    将整数形式的浮点数转换为浮点数
    
    Args:
        整数值: 整数形式的浮点数值
    
    Returns:
        float: 转换后的浮点数
    """
    import struct
    return struct.unpack('f', struct.pack('I', 整数值))[0]

def HD内存_双浮点长整数转双浮点数(长整数值: int) -> float:
    """
    将长整数形式的双精度浮点数转换为双精度浮点数
    
    Args:
        长整数值: 长整数形式的双精度浮点数值
    
    Returns:
        float: 转换后的双精度浮点数
    """
    import struct
    return struct.unpack('d', struct.pack('Q', 长整数值))[0]



from .config import Config, ctypes
from .config import auto_encode

# INT64 __stdcall HC_OpenCPU(int winIndex, BOOL mainThread);
def HD优化_开启CPU(窗口序号: int, 是否主线程: bool = False) -> int:
    """
    开启CPU优化
    
    Args:
        窗口序号: 窗口序号（从1开始）
        是否主线程: 是否需要主线程来调用这个CALL
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HC_OpenCPU = hd.HC_OpenCPU
    HC_OpenCPU.restype = ctypes.c_int64
    HC_OpenCPU.argtypes = [ctypes.c_int32, ctypes.c_bool]
    
    ret = HC_OpenCPU(ctypes.c_int32(窗口序号), ctypes.c_bool(是否主线程))
    return ret

# INT64 __stdcall HC_SetFPS(int winIndex, int fps);
def HD优化_设置FPS(窗口序号: int, 帧数: int = 0) -> int:
    """
    设置帧数（绑定dx.public.down.cpu后台属性有效）
    
    Args:
        窗口序号: 窗口序号（从1开始）
        帧数: 帧数（大于120表示关闭优化，可以用来在绑定后台的情况下关闭优化）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HC_SetFPS = hd.HC_SetFPS
    HC_SetFPS.restype = ctypes.c_int64
    HC_SetFPS.argtypes = [ctypes.c_int32, ctypes.c_int32]
    
    ret = HC_SetFPS(ctypes.c_int32(窗口序号), ctypes.c_int32(帧数))
    return ret


# __int64 __stdcall  HC_SetCpuDwonMs(__int32 窗口序号, __int32 downMs = 0);
def HD优化_设置延迟(窗口序号: int, downMs: int = 0) -> int:
    """
    设置延迟（绑定dx.public.down.cpu后台属性有效）

    Args:
        窗口序号: 窗口序号（从1开始）
        downMs:延迟毫秒数(自行根据实际情况而定一般在1ms到50ms之间)

    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()

    HC_SetCpuDwonMs = hd.HC_SetCpuDwonMs
    HC_SetCpuDwonMs.restype = ctypes.c_int64
    HC_SetCpuDwonMs.argtypes = [ctypes.c_int32, ctypes.c_int32]

    ret = HC_SetCpuDwonMs(ctypes.c_int32(窗口序号), ctypes.c_int32(downMs))
    return ret


# INT64 __stdcall HC_CloseCPU(int winIndex, BOOL mainThread);
def HD优化_关闭CPU(窗口序号: int, 是否主线程: bool = False) -> int:
    """
    关闭CPU优化
    
    Args:
        窗口序号: 窗口序号（从1开始）
        是否主线程: 是否需要主线程来调用这个CALL
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HC_CloseCPU = hd.HC_CloseCPU
    HC_CloseCPU.restype = ctypes.c_int64
    HC_CloseCPU.argtypes = [ctypes.c_int32, ctypes.c_bool]
    
    ret = HC_CloseCPU(ctypes.c_int32(窗口序号), ctypes.c_bool(是否主线程))
    return ret


class HD返回值:
    RET_检查PID存在 = 8
    RET_环境已卸载 = 7
    RET_重连窗口序号不一致 = 6
    RET_重连窗口 = 5
    RET_状态变动 = 4
    RET_暂停过 = 3
    RET_结束 = 2
    RET_成功 = 1
    RET_失败 = 0
    RET_真 = 1
    RET_非 = 0
    ERROR_未初始化全局环境 = -1000
    ERROR_未找到进程环境 = -1001
    ERROR_进程环境内存为NULL = -1002
    ERROR_获取CALL环境失败 = -1003
    ERROR_超时返回 = -1004
    ERROR_主线程调用超时返回 = -1005
    ERROR_数据异常 = -1006
    ERROR_参数错误 = -1007
    ERROR_未挂接主线程 = -1008
    ERROR_后台绑定句柄无效 = -1009
    ERROR_未绑定后台 = -1010
    ERROR_多开超出限制 = -1011
    ERROR_字符串为空 = -1012
    ERROR_地址为空 = -1013
    ERROR_未知错误 = -1014
    ERROR_远进程申请内存失败 = -1015
    ERROR_文件夹创建失败 = -1016
    ERROR_异步无法获取返回值 = -1017
    ERROR_语法错误 = -1018
    ERROR_申请内存失败 = -1019
    ERROR_创建线程失败 = -1020
    ERROR_缓冲区大小不足 = -1021
    ERROR_未初始化LUA = -1022
    ERROR_LUA状态机为NULL = -1023
    ERROR_未找到LUA函数 = -1024
    ERROR_返回值未知类型 = -1025
    ERROR_LUA线程标识符不符合 = -1026
    ERROR_模块获取失败 = -1027
    ERROR_地址不可读 = -1028
    ERROR_返回值为JSON = -1029
    ERROR_获取数据失败 = -1030
    ERROR_未初始化 = -1031
    ERROR_已经开启 = -1032
    ERROR_已经结束 = -1033
    ERROR_未开启 = -1034
    ERROR_未结束 = -1035
    ERROR_高宽为0 = -1036
    ERROR_数据为NULL = -1037
    ERROR_数据不符合要求 = -1038
    ERROR_文件打开失败 = -1039
    ERROR_打开失败 = -1040
    ERROR_解析失败 = -1041
    ERROR_无游戏类型 = -1042
    ERROR_HOOK失败 = -1043
    ERROR_UNHOOK失败 = -1044
    ERROR_功能失效 = -1045
    ERROR_无效PE文件格式 = -1046
    ERROR_未找到PE头 = -1047
    ERROR_重定位表失败 = -1048
    ERROR_未找到函数入口 = -1049
    ERROR_无法附加DLL = -1050
    ERROR_接口数量上限 = -1051
    ERROR_已经存在 = -1052
    ERROR_打开句柄失败 = -1053
    ERROR_未找到全局环境 = -1054
    ERROR_组件数量上限 = -1055
    ERROR_未找到组件接口 = -1056
    ERROR_接口类型不匹配 = -1057
    ERROR_组件无效 = -1058
    ERROR_接口地址无效 = -1059
    ERROR_生成密钥失败 = -1060
    ERROR_加密失败 = -1061
    ERROR_解密失败 = -1062
    ERROR_DLL中无此接口 = -1063
    ERROR_下载失败 = -1064
    ERROR_注册表操作失败 = -1065
    ERROR_路径获取失败 = -1066
    ERROR_提权失败 = -1067
    ERROR_驱动已安装 = -1068
    ERROR_HD驱动已安装无法安装HN驱动 = -1069
    ERROR_资源未找到 = -1070
    ERROR_资源加载失败 = -1071
    ERROR_提取资源失败 = -1072
    ERROR_未加载插件 = -1073
    ERROR_文件无法保存 = -1074
    ERROR_打开目录失败 = -1075
    ERROR_写入文件的字节大小不符合要求 = -1076
    ERROR_删除文件失败 = -1077
    ERROR_获取字符串失败 = -1078
    ERROR_获取注册表值失败 = -1079
    ERROR_类型错误 = -1080
    ERROR_参数不符合要求 = -1081
    ERROR_区域超出 = -1082
    ERROR_文件不存在 = -1083
    ERROR_创建文件失败 = -1084
    ERROR_文件读取失败 = -1085
    ERROR_与系统驱动通讯失败 = -1086
    ERROR_创建管道失败 = -1087
    ERROR_创建进程失败 = -1088
    ERROR_未找到相关字符串信息 = -1089
    ERROR_缓冲区大小不充足 = -1090
    ERROR_数据类型转换失败 = -1091
    ERROR_格式化字符串失败 = -1092
    ERROR_网络超时 = -1093
    ERROR_网络连接失败 = -1094
    ERROR_加载指定DLL失败 = -1095
    ERROR_解析字符串失败 = -1096
    ERROR_窗口大小变动导致数据不一致 = -1097
    ERROR_打开剪切板失败 = -1098
    ERROR_加锁失败 = -1099
    ERROR_获取剪切板数据失败 = -1100
    ERROR_版本号获取失败 = -1101
    ERROR_已经绑定其他设备 = -1102
    ERROR_已经达到最大在线数 = -1103
    ERROR_账号或密码为空 = -1104
    ERROR_验证失败 = -1105
    ERROR_打开进程失败 = -1106
    ERROR_进程位数不匹配 = -1107
    ERROR_添加进程环境失败 = -1108
    ERROR_定位特征地址失败 = -1109
    ERROR_寻找空白地址失败 = -1110
    ERROR_无操作类型 = -1111
    ERROR_无相关句柄 = -1112
    ERROR_无HDC句柄 = -1113
    ERROR_获取矩形大小失败 = -1114
    ERROR_拷贝数据失败 = -1115
    ERROR_无效句柄 = -1116
    ERROR_创建对象失败 = -1117
    ERROR_截图方式需要重开才能切换 = -1118
    ERROR_格式有误 = -1119
    ERROR_字库数据为空 = -1120
    ERROR_字库中未找到相应字 = -1121
    ERROR_大小计算为0 = -1122
    ERROR_容器大小不一致 = -1123
    ERROR_句柄无效 = -1124
    ERROR_获取PID无效 = -1125
    ERROR_获取大小失败 = -1126
    ERROR_获取失败 = -1127
    ERROR_未找到 = -1128
    ERROR_立即返回无效值 = -1129
    ERROR_未设置路径 = -1130
    ERROR_文件操作失败 = -1131
    ERROR_写入内存失败 = -1132
    ERROR_模块查找失败 = -1133
    ERROR_接口查找失败 = -1134
    ERROR_组件信息保存失败 = -1135
    ERROR_组件加载失败 = -1136
    ERROR_组件卸载失败 = -1137
    ERROR_组件不符合卸载要求 = -1138
    ERROR_进程环境句柄为NULL = -1139
    ERROR_未绑定PID = -1140
    ERROR_读取图片失败 = -1141
    ERROR_打开注册表失败 = -1142
    ERROR_获取注册表失败 = -1143
    ERROR_写内存失败 = -1144
    ERROR_清除缓存失败 = -1145
    ERROR_字体无宽度 = -1146
    ERROR_裁剪矩形数据失败 = -1147
    ERROR_图片无宽或高 = -1148
    ERROR_功能未开放 = -1149
    ERROR_模块信息获取失败 = -1150
    ERROR_未找到合适的JMP地址 = -1151
    ERROR_HOOK初始化失败 = -1152
    ERROR_无HOOK接口类型 = -1153
    ERROR_CALL类型不匹配 = -1154
    ERROR_创建通讯失败 = -1155
    ERROR_加载通讯失败 = -1156
    ERROR_数据格式错误 = -1157
    ERROR_地址失效 = -1158
    ERROR_坐标转换失败 = -1159
    ERROR_容器为空 = -1160
    ERROR_数据为空 = -1161
    ERROR_特征不符合 = -1162
    ERROR_范围未确定 = -1163
    ERROR_缓冲区不足 = -1164
    ERROR_此接口调试版本无效 = -1165
    ERROR_子图不在范围内 = -1166
    ERROR_插件数量上限 = -1167
    ERROR_API枚举失败 = -1168
    ERROR_无法定位模块 = -1169
    ERROR_无效HOOK地址 = -1170
    ERROR_无对应的HOOK函数 = -1171
    ERROR_破坏字节超过容量 = -1172
    ERROR_指定地址不适合HOOK = -1173
    ERROR_没有充足的HOOK大小 = -1174
    ERROR_设置回调地址失败 = -1175
    ERROR_API获取时间失败 = -1176
    ERROR_无效插件序号 = -1177
    ERROR_进程不存在 = -1178
    ERROR_未安装插件 = -1179
    ERROR_初始化通讯失败 = -1180
    ERROR_未初始化通讯序号 = -1181
    ERROR_当前线程字库为空 = -1182
    ERROR_线程数量超出限制 = -1183
    ERROR_字库序号不存在 = -1184
    ERROR_释放资源失败 = -1185
    ERROR_超出容量 = -1186
    ERROR_空模型 = -1187
    ERROR_环境序号不存在 = -1188
    ERROR_回调处理中 = -1189
    ERROR_无法操作绑定窗口 = -1190
    ERROR_接口已被移除 = -1191
    ERROR_不支持类型 = -1192
    ERROR_初始化失败 = -1193
    ERROR_环境被卸载 = -1194
    ERROR_进程已经关闭 = -1195
    ERROR_中控环境未初始化 = -1196
    ERROR_未加载HD驱动 = -1197
    ERROR_未绑定设备 = -1198
    ERROR_未找到进程 = -1199
    ERROR_进程PID不匹配 = -1200
    ERROR_前台模式无法后台 = -1201
    ERROR_JMP地址无效 = -1202
    ERROR_HOOK地址无效 = -1203
    ERROR_类型和HOOK地址不匹配 = -1204
    ERROR_不在HD多线程环境下 = -1205
    ERROR_未连接 = -1206
    ERROR_进程环境已被卸载 = -1207
    ERROR_安装插件失败 = -1208 #检查是否安装了驱动
    ERROR_安装驱动失败 = -1209 #检查是否管理员或者杀毒或者关闭内核隔离
    ERROR_加载环境失败 = -1210 #检查账号是否欠费或者网络问题或者参数不符合要求
    ERROR_初始化序号失败 = -1211 #一般不会失败
    ERROR_获取PID超时返回 = -1212 #确定是否打开进程成功或者增大等待时间
    ERROR_获取状态值20超时返回 = -1213 #未安装插件或被拦截或增大等待时间
    ERROR_获取状态值120超时返回 = -1214 #未安装插件或被拦截或增大等待时间
    ERROR_继续失败 = -1215 #可能未初始化相关环境 一般不会失败
    ERROR_当前进程插件序号不一致 = -1216 #说明指定的PID进程绑定的窗口序号已经存在  与指定的序号不一致  调用HCInject_GetPreWinIndex  获取指定PID的绑定的窗口序号
    ERROR_PID无效 = -1217
    ERROR_扩展序号不能用 = -1218#扩展序号不能自己指定
    ERROR_接口丢弃 = -1219 #老版本的接口丢弃
    ERROR_序号超出限制 = -1220
    ERROR_已经重启 = -1221
    ERROR_登录中无法重启 = -1222
    ERROR_暂停中无法重启 = -1223
    ERROR_操作中无法重启 = -1224
    ERROR_强制关闭线程中无法发送 = -1225
    ERROR_卸载失败 = -1226
    ERROR_未完全开启 = -1227
    ERROR_逻辑异常 = -1228
    ERROR_无法连接VNC = -1229
    ERROR_未连接过VNC = -1230
    ERROR_未关联过VM = -1231
    ERROR_未获取截图环境 = -1232
    ERROR_环境为NULL = -1233
    ERROR_区域无效 = -1234
    ERROR_继续当前操作 = -1235
    ERROR_加解密失败 = -1236
    ERROR_未安装驱动 = -1237
    ERROR_调试版本无法加解密 = -1238
    ERROR_截图缓存不存在 = -1239
    #=============================================
    LOGINERROR_错误 =  -2000 #如果大于这个值也表示成功 = 可能返回的是点数不足 = 小于这个值表示错误
    LOGINERROR_客户端数据为空 = -2001
    LOGINERROR_账号卡密不匹配 = -2002
    LOGINERROR_登记登录数据失败 = -2003
    LOGINERROR_客户端数据太多 = -2004
    LOGINERROR_未找到客户端数据 = -2005
    LOGINERROR_账号类型为空 = -2006
    LOGINERROR_账号扣点失败 = -2007
    LOGINERROR_更新客户端加载信息失败 = -2008
    LOGINERROR_账号点数不足 = -2009
    LOGINERROR_查询客户端加载信息失败 = -2010
    LOGINERROR_试用卡 = -2011
    LOGINERROR_发布版本无法使用测试账号 = -2012
    LOGINERROR_老版本丢弃 = -2013
    LOGINERROR_数据错误 = -2014
    #=============================================
    #驱动接口返回值： = 大于等于0 = 为成功 =  =  = 特殊:-1068为驱动已经安装 = 可以忽视！
    #驱动宏返回值
    #宏返回值
    #这个值必须大于0 = 用在最开始加载驱动的返回 = 小于0会蓝屏！！
    LOAD_SUCCESS = 0x00000001
    #下面的值是其他接口自定义返回值 = 必须小于0 = 大于0统一返回的都是0！！
    DRERROR_SUCCESS = 0x00000002
    DRERROR_SUCCESSEX = 0xE0000000
    DRERROR_SUCCESSTEST = 0xE0000001
    DRERROR_EXIST = 0xE0000002
    DRERROR_FAID = 0xE0000003
    DRERROR_无法打开进程 = 0xE0000004
    DRERROR_无效的句柄表 = 0xE0000005
    DRERROR_用户验证失败 = 0xE0000006
    DRERROR_内存类型不符 = 0xE0000007
    DRERROR_超出内存范围 = 0xE0000008
    DRERROR_隐藏内存失败 = 0xE0000009
    DRERROR_查询内存失败 = 0xE000000A
    DRERROR_申请内存失败 = 0xE000000B
    DRERROR_超出读写字节 = 0xE000000C
    DRERROR_分配内存失败 = 0xE000000D
    DRERROR_无效的缓冲区 = 0xE000000E
    DRERROR_无法结束自身 = 0xE000000F
    DRERROR_无法识别数据 = 0xE0000010
    DRERROR_进程位数错误 = 0xE0000011
    DRERROR_读写地址错误 = 0xE0000012
    DRERROR_劫持线程失败 = 0xE0000013
    DRERROR_X86DLL格式有误 = 0xE0000014
    DRERROR_X64DLL格式有误 = 0xE0000015
    DRERROR_无合适处理器 = 0xE0000016
    DRERROR_未找到鼠标 = 0xE0000017
    DRERROR_未找到键盘 = 0xE0000018
    DRERROR_未找到入口参数 = 0xE0000019#没有找到入口参数
    DRERROR_输入缓冲区为空 = 0xE0000020#输入缓冲区为空
    DRERROR_未找到模块基址 = 0xE0000021
    DRERROR_未找到函数地址 = 0xE0000022
    ERROR_参数有误 = 0xE0000023#参数有误



from .config import Config, ctypes
from .config import auto_encode

# INT64 __stdcall HCSH_GetShellCode(int 模式, char* 汇编文本, BYTE* 机器码缓冲区, int 机器码缓冲区大小, INT64* 返回机器码字节大小的地址, INT64* 错误1变量的地址, INT64* 错误2变量的地址);
def HD汇编_转机器码(模式: int, 汇编文本: str, 机器码缓冲区=None, 机器码缓冲区大小: int = 1024, 错误1=None, 错误2=None) -> tuple:
    """
    汇编文本转换机器码
    
    Args:
        模式: 32位(4)/64位(8)
        汇编文本: 汇编代码文本
        机器码缓冲区: 预分配缓冲区，默认自动创建
        机器码缓冲区大小: 缓冲区容量，单位字节
        错误1: 返回错误行号变量地址，需ctypes.c_int()
        错误2: 返回错误描述变量地址，需ctypes.c_char_p()
    
    Returns:
        tuple: (结果代码, 实际机器码, 实际字节数, 错误行号, 错误描述)
    """
    hd = Config.get_hd()
    
    HCSH_GetShellCode = hd.HCSH_GetShellCode
    HCSH_GetShellCode.restype = ctypes.c_int64
    HCSH_GetShellCode.argtypes = [
        ctypes.c_int32,
        ctypes.c_char_p,
        ctypes.POINTER(ctypes.c_ubyte),
        ctypes.c_int32,
        ctypes.POINTER(ctypes.c_int32),
        ctypes.POINTER(ctypes.c_int32),
        ctypes.POINTER(ctypes.c_char_p)
    ]
    
    # 准备输出参数
    actual_size = ctypes.c_int32(0)
    error_line = ctypes.c_int32(0)
    error_desc = ctypes.c_char_p()
    
    # 自动创建缓冲区
    if not 机器码缓冲区:
        机器码缓冲区 = (ctypes.c_ubyte * 机器码缓冲区大小)()
    
    # 调用函数
    ret = HCSH_GetShellCode(
        ctypes.c_int32(模式),
        auto_encode(汇编文本),
        机器码缓冲区,
        ctypes.c_int32(机器码缓冲区大小),
        ctypes.byref(actual_size),
        ctypes.byref(error_line) if 错误1 is None else 错误1,
        ctypes.byref(error_desc) if 错误2 is None else 错误2
    )
    
    # 提取结果
    result_bytes = bytes(机器码缓冲区)[:actual_size.value] if ret == 0 else b''
    return (
        ret,
        result_bytes,
        actual_size.value,
        error_line.value,
        error_desc.value.decode('utf-8', errors='ignore') if error_desc.value else ""
    )

# INT64 __stdcall HCSH_WriteShellCode(int pid, BYTE* 机器码缓冲区, int 机器码缓冲区大小, INT64* 返回变量的地址);
def HD汇编_写入机器码(目标进程PID: int, 机器码缓冲区: bytes, 返回地址变量=None) -> tuple:
    """
    将机器码写入目标进程内存
    
    Args:
        目标进程PID: 目标进程ID
        机器码缓冲区: 机器码bytes对象 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
        返回地址变量: 接收地址的ctypes变量，默认自动创建
    
    Returns:
        tuple: (结果代码, 写入的地址)
    """
    hd = Config.get_hd()
    
    HCSH_WriteShellCode = hd.HCSH_WriteShellCode
    HCSH_WriteShellCode.restype = ctypes.c_int64
    HCSH_WriteShellCode.argtypes = [
        ctypes.c_int32,
        ctypes.POINTER(ctypes.c_ubyte),
        ctypes.c_int32,
        ctypes.POINTER(ctypes.c_uint64)
    ]
    
    # 自动创建接收变量
    allocated_addr = ctypes.c_uint64(0) if 返回地址变量 is None else 返回地址变量
    
    # 转换缓冲区
    buffer_type = ctypes.c_ubyte * len(机器码缓冲区)
    buffer_ptr = buffer_type.from_buffer_copy(机器码缓冲区)
    
    ret = HCSH_WriteShellCode(
        ctypes.c_int32(目标进程PID),
        buffer_ptr,
        ctypes.c_int32(len(机器码缓冲区)),
        ctypes.byref(allocated_addr) if 返回地址变量 is None else 返回地址变量
    )
    
    return ret, allocated_addr.value if ret == 0 else 0



from .config import Config, ctypes
from .config import auto_encode

# ━━━━━━━━━━━━━━━━━━ 截图管理接口 ━━━━━━━━━━━━━━━━━━


class MYA8R8G8B8(ctypes.Structure):
    _pack_ = 1
    _fields_ = [
        ('m_a', ctypes.c_ubyte),
        ('m_r', ctypes.c_ubyte),
        ('m_g', ctypes.c_ubyte),
        ('m_b', ctypes.c_ubyte)
    ]

# INT64 __stdcall HCCS_SetType(int 模式);
def HD截图_设置识别模式(模式: int) -> int:
    """
    设置识别模式
    :param 窗口序号: 窗口序号 (从1开始)
    :return: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()

    HCCS_SetType = hd.HCCS_SetType
    HCCS_SetType.restype = ctypes.c_int64
    HCCS_SetType.argtypes = [ctypes.c_int32]

    ret = HCCS_SetType(ctypes.c_int32(模式))

    return ret

# INT64 __stdcall HCCS_OpenCS(int 窗口序号);
def HD截图_打开(窗口序号: int) -> int:
    """
    打开截图
    :param 窗口序号: 窗口序号 (从1开始)
    :return: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()

    HCCS_OpenCS = hd.HCCS_OpenCS
    HCCS_OpenCS.restype = ctypes.c_int64
    HCCS_OpenCS.argtypes = [ctypes.c_int32]

    ret = HCCS_OpenCS(ctypes.c_int32(窗口序号))

    return ret


# INT64 __stdcall HCCS_OpenCSEx(int 窗口序号, BOOL bNormal, int capType, INT64 hwnd);
def HD截图_打开Ex(窗口序号: int, 是否是通常模式: bool, 截图模式: int = 0, 窗口句柄: int = 0) -> int:
    """
    打开截图（扩展版本）
    :param 窗口序号: 窗口序号 (从1开始)
    :param 是否是通常模式: 是否是通常模式（一般为TRUE）
    :param 截图模式: 截图模式（查看HD截图模式） (默认0)
    :param 窗口句柄: 窗口句柄 (默认0)
    :return: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()

    HCCS_OpenCSEx = hd.HCCS_OpenCSEx
    HCCS_OpenCSEx.restype = ctypes.c_int64
    HCCS_OpenCSEx.argtypes = [ctypes.c_int32, ctypes.c_bool, ctypes.c_int32, ctypes.c_int64]

    ret = HCCS_OpenCSEx(
        ctypes.c_int32(窗口序号),
        ctypes.c_bool(是否是通常模式),
        ctypes.c_int32(截图模式),
        ctypes.c_int64(窗口句柄)
    )

    return ret


# INT64 __stdcall HCCS_CloseCS(int 窗口序号);
def HD截图_关闭(窗口序号: int) -> int:
    """
    关闭截图
    :param 窗口序号: 窗口序号 (从1开始)
    :return: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()

    HCCS_CloseCS = hd.HCCS_CloseCS
    HCCS_CloseCS.restype = ctypes.c_int64
    HCCS_CloseCS.argtypes = [ctypes.c_int32]

    ret = HCCS_CloseCS(ctypes.c_int32(窗口序号))

    return ret


def HD截图_关闭Ex(窗口序号: int) -> int:
    # INT64 __stdcall HCCS_CloseCSEx(INT32 窗口序号);
    """
    关闭截图（扩展版本）
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    func = hd.HCCS_CloseCSEx
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32]
    
    return func(窗口序号)


def HD截图_获取截图数据(窗口序号: int) -> int:
    # INT64 __stdcall HCCS_GetCSData(INT32 窗口序号);
    """
    获取截图数据
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        
    Returns:
        int: 返回值代码（查看HD返回值表），数据以JSON格式返回
    """
    hd = Config.get_hd()
    func = hd.HCCS_GetCSData
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32]
    
    return func(窗口序号)


def HD截图_打开查看器(窗口序号: int, X: int, Y: int, 宽度: int, 高度: int) -> int:
    # INT64 __stdcall HCCS_OpenCSFinder(INT32 窗口序号, INT32 X, INT32 Y, INT32 宽度, INT32 高度);
    """
    打开截图查看器
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        X: 查看器X坐标
        Y: 查看器Y坐标
        宽度: 查看器宽度
        高度: 查看器高度
        
    Returns:
        int: 返回值代码（查看HD返回值表），或者返回查看器的PID
    """
    hd = Config.get_hd()
    func = hd.HCCS_OpenCSFinder
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32]
    
    return func(窗口序号, X, Y, 宽度, 高度)


def HD截图_关闭查看器(窗口序号: int, pid: int) -> int:
    # INT64 __stdcall HCCS_CloseCSFinder(INT32 窗口序号, INT32 pid);
    """
    关闭截图查看器
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        pid: 查看器的进程PID
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    func = hd.HCCS_CloseCSFinder
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_int32]
    
    return func(窗口序号, pid)


def HD截图_截图(窗口序号: int, BMP文件路径: str, 是否打开: bool = False) -> int:
    # INT64 __stdcall HCCS_CaptureBmp(INT32 窗口序号, LPCSTR BMP文件路径, BOOL 是否打开);
    """
    截图并保存为BMP图片文件
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        BMP文件路径: BMP文件路径+文件名
        是否打开: 是否打开查看图片
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    func = hd.HCCS_CaptureBmp
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_bool]
    
    return func(窗口序号, auto_encode(BMP文件路径), 是否打开)


def HD截图_获取BMP截图数据(窗口序号: int) -> int:
    # INT64 __stdcall HCCS_GetCaptureBmpData(INT32 窗口序号);
    """
    获取BMP截图数据
    
    Args:
        窗口序号: 窗口序号 (从1开始)
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
             数据在json字符串中
             json: {"error":0,"ret":[{"bRet":1,"addr":XXX,"eleSize":YYY,"allLen":ZZZ,"w":1222,"h":699}]}
             XXX是图片二进制数据首地址
             YYY是MYA8R8G8B8结构体数量
             ZZZ:总字节大小等于(54+YYY*sizeof(MYA8R8G8B8))
             w:宽度
             h:高度
             注意:拿到图片地址数据XXX使用后 记得释放(HCCS_FreeArray)
    """
    hd = Config.get_hd()
    func = hd.HCCS_GetCaptureBmpData
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32]
    
    return func(窗口序号)


def HD截图_释放数据(需要释放的地址: int) -> int:
    # INT64 __stdcall HCCS_FreeArray(INT64 addr);
    """
    释放内存
    
    Args:
        需要释放的地址: 需要释放的地址
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
             释放内存 该内存是使用 new[] 申请的内存
    """
    hd = Config.get_hd()
    func = hd.HCCS_FreeArray
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int64]
    
    return func(需要释放的地址)


def HD截图_释放内存池数据(窗口序号: int, 需要释放的地址: int) -> int:
    # INT64 __stdcall HCCS_FreeMemPool(INT32 窗口序号, INT64 addr);
    """
    释放内存,内存池操作释放内存
    我们获取了截图数据不需要了都需要调用这个接口来释放掉,防止内存泄露
    那个窗口序号返回申请的地址 就用那个窗口序号释放
    注意:该接口是释放【使用内存池申请的内存地址】的地址,与HCCS_FreeArray不一样
    
    Args:
        窗口序号: 窗口序号
        需要释放的地址: 需要释放的地址
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
             释放内存 该内存是使用 new[] 申请的内存
    """
    hd = Config.get_hd()
    func = hd.HCCS_FreeMemPool
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_int64]
    
    return func(窗口序号, 需要释放的地址)


def HD截图_是否后台缓存失败(传递的返回值: int) -> int:
    # INT64 __stdcall HCCS_IsCaptureValid(INT64 ret);
    """
    后台截图缓存获取失败判断接口
    可以自行加一个容错次数,再这个次数内多次识别,直到找到
    
    Args:
        传递的返回值: 传递的返回值 必须是识别截图相关的接口返回的
        
    Returns:
        int: 返回值代码 (查看HD返回值表)
             释放内存 该内存是使用 new[] 申请的内存
    """
    hd = Config.get_hd()
    func = hd.HCCS_IsCaptureValid
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int64]
    
    return func(传递的返回值)





from .config import Config, ctypes
from .config import auto_encode

# INT64 __stdcall HCHD_LoadDrv();
def HD驱动_安装() -> int:
    """
    加载HD驱动
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_LoadDrv
    func.restype = ctypes.c_int64
    func.argtypes = []
    
    return func()

# INT64 __stdcall HCHD_LoadDrv2(int type);
def HD驱动_安装2(驱动类型: int = 0) -> int:
    """
    云下发加载驱动或组件（可指定驱动序号加载不同版本的驱动）
    
    Args:
        驱动类型: 驱动序号，-1正式驱动，0定制版本，1备用版本，2~6为其他组件，默认0
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_LoadDrv2
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int]
    
    return func(驱动类型)

# INT64 __stdcall HCHD_InitFastRW();
def HD驱动_初始化快速读写() -> int:
    """
    初始化HD驱动快速读写(一般在HD安装驱动接口后的下一句就开始初始化)
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()

    func = hd.HCHD_InitFastRW
    func.restype = ctypes.c_int64
    func.argtypes = []

    return func()

# __int64 __stdcall HCHD_InjectX86X64(char* injectExeName, __int32 dllBits, __int32 injectMode, __int32 memoryHide, PVOID injectData, __int32 injectSize);
def HD驱动_无痕注入DLL(injectExeName: str, dllBits: int, injectMode: int, memoryHide: int, injectData: bytes, injectSize: int) -> int:
    """
    把DLL注入到指定进程中
    
    Args:
        injectExeName: 进程名(如:Game.exe)
        dllBits: 进程位(32/64)
        injectMode: 注入模式(0/1/2),一般0,1模式就行,2用于steam游戏
        memoryHide: 内存保护模式(0/1/2)
        injectData: 注入数据缓冲区首地址 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
        injectSize: 注入数据缓冲区大小(单位:字节)
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()

    func = hd.HCHD_InjectX86X64
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_char_p, ctypes.c_int, ctypes.c_int, ctypes.c_int, ctypes.c_void_p, ctypes.c_int]

    return func(
        auto_encode(injectExeName),
        dllBits, injectMode, memoryHide,
        ctypes.c_char_p(injectData), injectSize
    )

# __int64 __stdcall HCHD_InstallPlugX86(char* injectExeName, __int32 injectMode, __int32 memoryHide);
def HD驱动_无痕安装插件X86(injectExeName: str, injectMode: int, memoryHide: int) -> int:
    """
    安装HD插件到指定进程中(X86版本)
    
    Args:
        injectExeName: 进程名(如:Game.exe)
        injectMode: 注入模式(0/1/2),一般0,1模式就行,2用于steam游戏
        memoryHide: 内存保护模式(0/1/2)
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()

    func = hd.HCHD_InstallPlugX86
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_char_p, ctypes.c_int, ctypes.c_int]

    return func(auto_encode(injectExeName), injectMode, memoryHide)

# __int64 __stdcall HCHD_InstallPlugX64(char* injectExeName, __int32 injectMode, __int32 memoryHide);
def HD驱动_无痕安装插件X64(injectExeName: str, injectMode: int, memoryHide: int) -> int:
    """
    安装HD插件到指定进程中(X64版本)
    
    Args:
        injectExeName: 进程名(如:Game.exe)
        injectMode: 注入模式(0/1/2),一般0,1模式就行,2用于steam游戏
        memoryHide: 内存保护模式(0/1/2)
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()

    func = hd.HCHD_InstallPlugX64
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_char_p, ctypes.c_int, ctypes.c_int]

    return func(auto_encode(injectExeName), injectMode, memoryHide)

# INT64 __stdcall HCHD_UnInstallPlug();
def HD驱动_卸载插件() -> int:
    """
    卸载插件（并不是从进程中卸载，而是清除了下一次进程打开的时候安装插件的缓存）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_UnInstallPlug
    func.restype = ctypes.c_int64
    func.argtypes = []
    
    return func()


#  __int64 __stdcall  HCHD_SetMMTrackType(__int32 type);
def HD驱动_设置鼠标轨迹(type: int) -> int:
    """
    前台鼠标移动点击

    Args:
        type:轨迹类型 -1或0 表示无轨迹  1 表示随机轨迹 2表示直线轨迹 3表示直线波动轨迹(过检测强)  具体的轨迹效果可以参考:后台键鼠的轨迹

    Returns:
        int: 返回值代码（查看HD返回值表） 返回之前的轨迹类型
    """
    hd = Config.get_hd()

    func = hd.HCHD_SetMMTrackType
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int]

    return func(type)



# INT64 __stdcall HCHD_MousePress(int abx, int aby, int mButCode, int mis);
def HD驱动_前台鼠标移动点击(X坐标: int, Y坐标: int, 鼠标按钮代码: int, 间隔毫秒: int) -> int:
    """
    前台鼠标移动点击
    
    Args:
        X坐标: 屏幕坐标X
        Y坐标: 屏幕坐标Y
        鼠标按钮代码: 鼠标按钮值（1=左按下, 2=左弹起, 4=中按下, 8=中弹起, 16=右按下, 32=右弹起）
        间隔毫秒: 按下和弹起之间的毫秒差
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_MousePress
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int, ctypes.c_int, ctypes.c_int]
    
    return func(X坐标, Y坐标, 鼠标按钮代码, 间隔毫秒)

# INT64 __stdcall HCHD_MousePressEx(INT64 hwnd, int x, int y, int mButCode, int mis);
def HD驱动_前台鼠标移动点击Ex(窗口句柄: int, X坐标: int, Y坐标: int, 鼠标按钮代码: int, 间隔毫秒: int) -> int:
    """
    前台驱动鼠标移动并点击（可指定句柄）
    
    Args:
        窗口句柄: 窗口句柄
        X坐标: 窗口客户区坐标X
        Y坐标: 窗口客户区坐标Y
        鼠标按钮代码: 鼠标按钮值（1=左按下, 2=左弹起, 4=中按下, 8=中弹起, 16=右按下, 32=右弹起）
        间隔毫秒: 按下和弹起之间的毫秒差
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_MousePressEx
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int64, ctypes.c_int, ctypes.c_int, ctypes.c_int, ctypes.c_int]
    
    return func(窗口句柄, X坐标, Y坐标, 鼠标按钮代码, 间隔毫秒)

# INT64 __stdcall HCHD_MouseDown(INT64 hwnd, int x, int y, int mButCode);
def HD驱动_前台鼠标移动按下(窗口句柄: int, X坐标: int, Y坐标: int, 鼠标按钮代码: int) -> int:
    """
    前台驱动鼠标移动并按下
    
    Args:
        窗口句柄: 窗口句柄
        X坐标: 窗口客户区坐标X
        Y坐标: 窗口客户区坐标Y
        鼠标按钮代码: 鼠标按钮值（1=左按下, 4=中按下, 16=右按下）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_MouseDown
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int64, ctypes.c_int, ctypes.c_int, ctypes.c_int]
    
    return func(窗口句柄, X坐标, Y坐标, 鼠标按钮代码)

# INT64 __stdcall HCHD_MouseUp(INT64 hwnd, int x, int y, int mButCode);
def HD驱动_前台鼠标移动弹起(窗口句柄: int, X坐标: int, Y坐标: int, 鼠标按钮代码: int) -> int:
    """
    前台驱动鼠标移动并弹起
    
    Args:
        窗口句柄: 窗口句柄
        X坐标: 窗口客户区坐标X
        Y坐标: 窗口客户区坐标Y
        鼠标按钮代码: 鼠标按钮值（2=左弹起, 8=中弹起, 32=右弹起）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_MouseUp
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int64, ctypes.c_int, ctypes.c_int, ctypes.c_int]
    
    return func(窗口句柄, X坐标, Y坐标, 鼠标按钮代码)

# INT64 __stdcall HCHD_KbPress(int virtualKeyCode, int mis);
def HD驱动_前台按键(虚拟键码: int, 间隔毫秒: int) -> int:
    """
    前台驱动键盘（按下并弹起）
    
    Args:
        虚拟键码: 虚拟键码
        间隔毫秒: 按下和弹起之间的毫秒差
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_KbPress
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int]
    
    return func(虚拟键码, 间隔毫秒)

# INT64 __stdcall HCHD_KbDown(int virtualKeyCode);
def HD驱动_前台按键按下(虚拟键码: int) -> int:
    """
    前台驱动键盘（按下）
    
    Args:
        虚拟键码: 虚拟键码
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_KbDown
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int]
    
    return func(虚拟键码)

# INT64 __stdcall HCHD_KbUp(int virtualKeyCode);
def HD驱动_前台按键弹起(虚拟键码: int) -> int:
    """
    前台驱动键盘（弹起）
    
    Args:
        虚拟键码: 虚拟键码
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_KbUp
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int]
    
    return func(虚拟键码)

# INT64 __stdcall HCHD_RW(int pid, INT64 targetAddress, INT64 bufferAddress, int bufferOfBytes, int rwType);
def HD驱动_驱动读写(进程PID: int, 目标地址: int, 缓冲区地址: int, 缓冲区大小: int, 读写类型: int) -> int:
    """
    驱动读写
    
    Args:
        进程PID: 进程ID
        目标地址: 目标地址
        缓冲区地址: 数据缓冲区指针
        缓冲区大小: 数据缓冲区大小
        读写类型: 读写类型（0=读内存, 1=写内存, 2=强写内存）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_RW
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int64, ctypes.c_int64, ctypes.c_int, ctypes.c_int]
    
    v2 = ctypes.cast(缓冲区地址, ctypes.c_void_p)
    v3 = int(v2.value)
    
    return func(进程PID, 目标地址, v3, 缓冲区大小, 读写类型)

# INT64 __stdcall HCHD_RWEx(INT64 targetAddress, INT64 bufferAddress, int bufferOfBytes, int rwType);
def HD驱动_驱动读写Ex(目标地址: int, 缓冲区地址: int, 缓冲区大小: int, 读写类型: int) -> int:
    """
    驱动读写Ex（批量读写）
    
    Args:
        目标地址: 目标地址
        缓冲区地址: 数据缓冲区指针
        缓冲区大小: 数据缓冲区大小
        读写类型: 读写类型（0=读内存, 1=写内存, 2=强写内存）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_RWEx
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int64, ctypes.c_int64, ctypes.c_int, ctypes.c_int]
    
    v2 = ctypes.cast(缓冲区地址, ctypes.c_void_p)
    v3 = int(v2.value)

    return func(目标地址, v3, 缓冲区大小, 读写类型)

# INT64 __stdcall HCHD_BeginRWEx(int pid);
def HD驱动_开始读写(进程PID: int) -> int:
    """
    驱动读写Ex（开始批读写）与HD驱动_结束读写成对出现，适合快速遍历
    
    Args:
        进程PID: 进程ID
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_BeginRWEx
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int]
    
    return func(进程PID)

# INT64 __stdcall HCHD_EndRWEx();
def HD驱动_结束读写(进程PID: int) -> int:
    """
    驱动读写Ex（结束批读写）与HD驱动_开始读写成对出现，适合快速遍历
    
    Args:
        进程PID: 进程ID（实际API不需要此参数，保持向下兼容）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_EndRWEx
    func.restype = ctypes.c_int64
    func.argtypes = []
    
    return func()

# INT64 __stdcall HCHD_AddrIsRead(int pid, INT64 addr, int size);
def HD驱动_地址是否可读(进程PID: int, 地址: int, 字节大小: int) -> int:
    """
    地址是否可读
    
    Args:
        进程PID: 进程ID
        地址: 需要测试的地址
        字节大小: 地址所涉及到的字节大小（4字节或者8字节），不能为其他字节数
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_AddrIsRead
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int64, ctypes.c_int]
    
    return func(进程PID, 地址, 字节大小)

# INT64 __stdcall HCHD_PP(int pid, BOOL bOpen);
def HD驱动_进程保护(进程PID: int, 是否开启: bool) -> int:
    """
    进程保护
    
    Args:
        进程PID: 进程ID
        是否开启: 是否开启保护（True=开启保护, False=关闭保护）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_PP
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_bool]
    
    return func(进程PID, 是否开启)

# INT64 __stdcall HCHD_PHide(int pid);
def HD驱动_进程隐藏(进程PID: int) -> int:
    """
    进程隐藏
    
    Args:
        进程PID: 进程ID
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_PHide
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int]
    
    return func(进程PID)

# INT64 __stdcall HCHD_PShow(int pid);
def HD驱动_进程显示(进程PID: int) -> int:
    """
    进程显示
    
    Args:
        进程PID: 进程ID
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_PShow
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int]
    
    return func(进程PID)

# __int64 __stdcall  HCHD_PPKill(char* processName,__int32 pid);
def HD_进程杀死(
    processName: str,
    pid: int
) -> int:
    """
    进程杀死
    Args:
        processName (str): 进程名，把当前所有相同进程名全部杀掉
        pid (int): 进程PID，指定了PID进程名就失效
    Returns:
        int: 返回值代码 (查看HD返回值表)
    """
    hd = Config.get_hd()
    func = hd.HCHD_PPKill
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_char_p, ctypes.c_int]
    
    return func(auto_encode(processName), pid)


# INT64 __stdcall HCHD_MemoryAllocate(int pid, INT64 memorySize, int memoryProtect, BOOL bHighAddress, INT64 pOutBuffer);
def HD驱动_申请内存(进程PID: int, 内存大小: int, 内存保护属性: int, 是否高位内存: bool, 输出缓冲区: int) -> int:
    """
    驱动申请内存
    
    Args:
        进程PID: 进程ID
        内存大小: 申请大小
        内存保护属性: 内存保护属性，例如0x40（64）可读可写可执行
        是否高位内存: 是否申请高位内存
        输出缓冲区: 缓冲区指针（存申请返回的地址）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_MemoryAllocate
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int64, ctypes.c_int, ctypes.c_bool, ctypes.c_int64]
    
    v2 = ctypes.cast(输出缓冲区, ctypes.c_void_p)
    v3 = int(v2.value)
    
    return func(进程PID, 内存大小, 内存保护属性, 是否高位内存, v3)

# INT64 __stdcall HCHD_MemoryAllocateEx(int pid, INT64 memoryAddr, INT64 memorySize, int memoryProtect, BOOL bHighAddress, INT64 pOutBuffer);
def HD驱动_申请内存Ex(进程PID: int, 内存地址: int, 内存大小: int, 内存保护属性: int, 是否高位内存: bool, 输出缓冲区: int) -> int:
    """
    驱动申请内存（扩展版本）
    
    Args:
        进程PID: 进程ID
        内存地址: 指定的内存地址或者为NULL（0）
        内存大小: 申请大小
        内存保护属性: 内存保护属性
        是否高位内存: 是否申请高位内存
        输出缓冲区: 缓冲区指针（存申请返回的地址）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_MemoryAllocateEx
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int64, ctypes.c_int64, ctypes.c_int, ctypes.c_bool, ctypes.c_int64]
    
    v2 = ctypes.cast(输出缓冲区, ctypes.c_void_p)
    v3 = int(v2.value)
    
    return func(进程PID, 内存地址, 内存大小, 内存保护属性, 是否高位内存, v3)

# INT64 __stdcall HCHD_MemoryFree(int pid, INT64 memoryAddress);
def HD驱动_内存释放(进程PID: int, 内存地址: int) -> int:
    """
    驱动内存释放
    
    Args:
        进程PID: 进程ID
        内存地址: 需要释放的内存地址
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_MemoryFree
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int64]
    
    return func(进程PID, 内存地址)

# INT64 __stdcall HCHD_MemoryProtect(int pid, INT64 memoryAddress, INT64 memoryOfBytes, int newProtect);
def HD驱动_修改内存保护(进程PID: int, 内存地址: int, 内存字节数: int, 新保护值: int) -> int:
    """
    驱动修改内存保护属性
    
    Args:
        进程PID: 进程ID
        内存地址: 内存地址
        内存字节数: 内存大小
        新保护值: 新保护值
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_MemoryProtect
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int64, ctypes.c_int64, ctypes.c_int]
    
    return func(进程PID, 内存地址, 内存字节数, 新保护值)

# INT64 __stdcall HCHD_MemoryHide(int pid, INT64 memoryAddress, INT64 memoryOfBytes);
def HD驱动_内存隐藏(进程PID: int, 内存地址: int, 内存字节数: int) -> int:
    """
    驱动内存隐藏
    
    Args:
        进程PID: 进程ID
        内存地址: 内存地址
        内存字节数: 内存大小
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_MemoryHide
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int64, ctypes.c_int64]
    
    return func(进程PID, 内存地址, 内存字节数)

# INT64 __stdcall HCHD_MemoryQuery(int pid, INT64 memoryAddress, PVOID pOutBuffer);
def HD驱动_内存查询(进程PID: int, 内存地址: int, 输出缓冲区: int) -> int:
    """
    驱动内存查询
    
    Args:
        进程PID: 进程ID
        内存地址: 内存地址
        输出缓冲区: 缓冲区指针（这里固定使用的是64位的MEMORY_BASIC_INFORMATION结构体，结构体大小48字节）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_MemoryQuery
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int64, ctypes.c_void_p]
    
    v2 = ctypes.cast(输出缓冲区, ctypes.c_void_p)
    v3 = int(v2.value)
    
    return func(进程PID, 内存地址, ctypes.c_void_p(v3))

# __int64 __stdcall HCHD_MemoryFindCode(__int32 pid, __int64 address, __int64 siginCode, __int32 siginCodeSize, __int32 iProtect, __int64 outBuffer);
def HD驱动_特征码查找地址(pid: int, address: int, siginCode: int, siginCodeSize: int, iProtect: int, outBuffer: int) -> int:
    """
    驱动特征码查找地址
    
    Args:
        pid: 进程ID
        address: 起始搜索地址
        siginCode: 特征码(二进制缓冲区不是字符串)
        siginCodeSize: 特征码长度(字节单位)
        iProtect: 要搜索的内存保护属性
        outBuffer: 缓冲区(存地址)
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_MemoryFindCode
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int64, ctypes.c_int64, ctypes.c_int, ctypes.c_int, ctypes.c_int64]
    
    v2 = ctypes.cast(outBuffer, ctypes.c_void_p)
    v3 = int(v2.value)
    
    return func(pid, address, siginCode, siginCodeSize, iProtect, v3)

# __int64 __stdcall HCHD_GetMainModuleBase(__int32 pid, __int64 outBuffer);
def HD驱动_获取主模块地址(pid: int, outBuffer: int) -> int:
    """
    获取主模块地址
    
    Args:
        pid: 进程ID
        outBuffer: 缓冲区(存地址)
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_GetMainModuleBase
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int64]
    
    v2 = ctypes.cast(outBuffer, ctypes.c_void_p)
    v3 = int(v2.value)
    
    return func(pid, v3)

# __int64 __stdcall HCHD_GetModuleBase(__int32 pid, char* moduleName, __int64 outBuffer);
def HD驱动_获取模块地址(pid: int, moduleName: str, outBuffer: int) -> int:
    """
    获取模块地址
    
    Args:
        pid: 进程ID
        moduleName: 模块名(Ascii字符串)
        outBuffer: 缓冲区(存地址)
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_GetModuleBase
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_char_p, ctypes.c_int64]
    
    v2 = ctypes.cast(outBuffer, ctypes.c_void_p)
    v3 = int(v2.value)
    
    return func(pid, auto_encode(moduleName), v3)

# __int64  __stdcall HCHD_GetModuleCallAddr(__int32 pid, char* moduleName, char* callName, __int64 outBuffer);
def HD驱动_获取模块函数地址(pid: int, moduleName: str, callName: str, outBuffer: int) -> int:
    """
    获取模块函数地址
    
    Args:
        pid: 进程ID
        moduleName: 模块名(Ascii字符串)
        callName: 函数名(Ascii字符串)
        outBuffer: 缓冲区(存地址)
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_GetModuleCallAddr
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_int64]
    
    v2 = ctypes.cast(outBuffer, ctypes.c_void_p)
    v3 = int(v2.value)
    
    return func(pid, auto_encode(moduleName), auto_encode(callName), v3)

# __int64 __stdcall HCHD_NTNCaptureScreen(__int64 hWnd, BOOL Enable);
def HD驱动_反截图(hWnd: int, Enable: bool) -> int:
    """
    反截图功能
    
    Args:
        hWnd: 窗口句柄
        Enable: 是否启用
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_NTNCaptureScreen
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int64, ctypes.c_bool]
    
    return func(hWnd, Enable)

# __int64 __stdcall HCHD_NTThreadRunCall(__int32 pid, __int64 callAddress);
def HD驱动_远线程执行CALL(pid: int, callAddress: int) -> int:
    """
    远线程执行CALL
    
    Args:
        pid: 进程ID
        callAddress: 函数地址
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_NTThreadRunCall
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int64]
    
    return func(pid, callAddress)

# __int64 __stdcall HCHD_ChangeMachineKey(__int32 type);
def HD驱动_修改机器码(type: int) -> int:
    """
    修改机器码
    
    Args:
        type: 参数类型
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_ChangeMachineKey
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int]

    return func(type)

# INT64 __stdcall HCHD_ClearInject();
def HD驱动_清除注入缓存() -> int:
    """
    驱动清除注入缓存(全局插件缓存,DLL缓存)
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_ClearInject
    func.restype = ctypes.c_int64
    func.argtypes = []
    
    return func()

# INT64 __stdcall HCHD_PcrocessRoot(int pid);
def HD驱动_进程提权(pid: int) -> int:
    """
    驱动进程提权
    
    Args:
        pid: 进程ID
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_PcrocessRoot
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int]
    
    return func(pid)

# INT64 __stdcall HCHD_PcrocessRootEx(INT64 handle);
def HD驱动_进程提权Ex(handle: int) -> int:
    """
    进程提权（扩展版本）
    
    Args:
        handle: 句柄
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCHD_PcrocessRootEx
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int64]
    
    return func(handle)




from .config import Config, ctypes
from .config import auto_encode

# INT64 __stdcall HCHDVT_AllocateMemory(int pid, int size);
def HDVT_申请内存(进程PID: int, 内存大小: int) -> int:
    """
    VT驱动申请内存
    
    Args:
        进程PID: 目标进程PID
        内存大小: 申请内存大小（字节）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    
    Note:
        需要调用HCHD_LoadDrv2传递参数2来安装HDVT驱动
    """
    hd = Config.get_hd()
    
    HCHDVT_AllocateMemory = hd.HCHDVT_AllocateMemory
    HCHDVT_AllocateMemory.restype = ctypes.c_int64
    HCHDVT_AllocateMemory.argtypes = [ctypes.c_int32, ctypes.c_int32]
    
    ret = HCHDVT_AllocateMemory(ctypes.c_int32(进程PID), ctypes.c_int32(内存大小))
    return ret

# INT64 __stdcall HCHDVT_FreeMemory(int pid, INT64 addr, int size);
def HDVT_释放内存(进程PID: int, 内存地址: int, 内存大小: int) -> int:
    """
    VT驱动释放内存
    
    Args:
        进程PID: 目标进程PID
        内存地址: 释放地址（由HCHDVT_AllocateMemory申请的内存地址）
        内存大小: 申请内存大小（字节）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    
    Note:
        需要调用HCHD_LoadDrv2传递参数2来安装HDVT驱动
    """
    hd = Config.get_hd()
    
    HCHDVT_FreeMemory = hd.HCHDVT_FreeMemory
    HCHDVT_FreeMemory.restype = ctypes.c_int64
    HCHDVT_FreeMemory.argtypes = [ctypes.c_int32, ctypes.c_int64, ctypes.c_int32]
    
    ret = HCHDVT_FreeMemory(ctypes.c_int32(进程PID), ctypes.c_int64(内存地址), ctypes.c_int32(内存大小))
    return ret

# INT64 __stdcall HCHDVT_Read(int pid, INT64 addr, void* buffer, int size);
def HDVT_读内存(进程PID: int, 内存地址: int, 数据缓冲区, 读取大小: int) -> int:
    """
    VT驱动读内存
    
    Args:
        进程PID: 目标进程PID
        内存地址: 读取的内存地址
        数据缓冲区: 读数据缓冲区（ctypes数组对象，可用create_string_buffer创建）
        读取大小: 读取的大小（字节）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    
    Note:
        需要调用HCHD_LoadDrv2传递参数2来安装HDVT驱动
    """
    hd = Config.get_hd()
    
    HCHDVT_Read = hd.HCHDVT_Read
    HCHDVT_Read.restype = ctypes.c_int64
    HCHDVT_Read.argtypes = [ctypes.c_int32, ctypes.c_int64, ctypes.c_void_p, ctypes.c_int32]
    
    buffer_ptr = ctypes.cast(数据缓冲区, ctypes.c_void_p)
    
    ret = HCHDVT_Read(ctypes.c_int32(进程PID), ctypes.c_int64(内存地址), buffer_ptr, ctypes.c_int32(读取大小))
    return ret

# INT64 __stdcall HCHDVT_Write(int pid, INT64 addr, void* buffer, int size);
def HDVT_写内存(进程PID: int, 内存地址: int, 数据缓冲区, 写入大小: int) -> int:
    """
    VT驱动写内存
    
    Args:
        进程PID: 目标进程PID
        内存地址: 内存写入地址
        数据缓冲区: 写入数据缓冲区（ctypes数组对象，可用create_string_buffer创建）
        写入大小: 写入数据的大小（字节）
    
    Returns:
        int: 驱动返回值代码（查看HD返回值表）
    
    Note:
        需要调用HCHD_LoadDrv2传递参数2来安装HDVT驱动
    """
    hd = Config.get_hd()
    
    HCHDVT_Write = hd.HCHDVT_Write
    HCHDVT_Write.restype = ctypes.c_int64
    HCHDVT_Write.argtypes = [ctypes.c_int32, ctypes.c_int64, ctypes.c_void_p, ctypes.c_int32]
    
    ret = HCHDVT_Write(ctypes.c_int32(进程PID), ctypes.c_int64(内存地址), 数据缓冲区, ctypes.c_int32(写入大小))
    return ret

# INT64 __stdcall HCHDVT_GetModule(int pid, char* moduleName);
def HDVT_获取模块地址(进程PID: int, 模块名称: str) -> int:
    """
    VT驱动获取模块基地址
    
    Args:
        进程PID: 目标进程PID
        模块名称: 模块名称（例如："kernel32.dll"）
    
    Returns:
        int: 模块地址（若返回负值为错误码，参照HD返回值表）
    
    Note:
        需要调用HCHD_LoadDrv2传递参数2来安装HDVT驱动
    """
    hd = Config.get_hd()
    
    HCHDVT_GetModule = hd.HCHDVT_GetModule
    HCHDVT_GetModule.restype = ctypes.c_int64
    HCHDVT_GetModule.argtypes = [ctypes.c_int32, ctypes.c_char_p]
    
    ret = HCHDVT_GetModule(ctypes.c_int32(进程PID), auto_encode(模块名称))
    return ret

# INT64 __stdcall HCHDVT_GetModuleFun(int pid, INT64 moduleAddr, char* functionName);
def HDVT_获取模块函数地址(进程PID: int, 模块地址: int, 函数名称: str) -> int:
    """
    VT驱动获取模块内函数地址
    
    Args:
        进程PID: 目标进程PID
        模块地址: 模块基地址
        函数名称: 函数名称（ASCII编码的字符串）
    
    Returns:
        int: 函数地址值
    
    Note:
        需要调用HCHD_LoadDrv2传递参数2来安装HDVT驱动
    """
    hd = Config.get_hd()
    
    HCHDVT_GetModuleFun = hd.HCHDVT_GetModuleFun
    HCHDVT_GetModuleFun.restype = ctypes.c_int64
    HCHDVT_GetModuleFun.argtypes = [ctypes.c_int32, ctypes.c_int64, ctypes.c_char_p]
    
    ret = HCHDVT_GetModuleFun(ctypes.c_int32(进程PID), ctypes.c_int64(模块地址), auto_encode(函数名称))
    return ret

# INT64 __stdcall HCHDVT_Hook(int pid, INT64 addr, void* hookData, int size, int hookType);
def HDVT_无痕HOOK(进程PID: int, HOOK地址: int, HOOK数据: bytes, 数据大小: int, HOOK类型: int) -> int:
    """
    VT驱动无痕HOOK
    
    Args:
        进程PID: 目标进程PID
        HOOK地址: HOOK的内存地址
        HOOK数据: HOOK数据缓冲区 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
        数据大小: HOOK数据大小
        HOOK类型: HOOK类型
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    
    Note:
        需要调用HCHD_LoadDrv2传递参数2来安装HDVT驱动
    """
    hd = Config.get_hd()
    
    HCHDVT_Hook = hd.HCHDVT_Hook
    HCHDVT_Hook.restype = ctypes.c_int64
    HCHDVT_Hook.argtypes = [ctypes.c_int32, ctypes.c_int64, ctypes.c_void_p, ctypes.c_int32, ctypes.c_int32]
    
    ret = HCHDVT_Hook(ctypes.c_int32(进程PID), ctypes.c_int64(HOOK地址), HOOK数据, ctypes.c_int32(数据大小), ctypes.c_int32(HOOK类型))
    return ret

# INT64 __stdcall HCHDVT_RemoteCall(int pid, void* shellcodeData, int size);
def HDVT_远程执行(进程PID: int, 执行数据: bytes, 数据大小: int = None) -> int:
    """
    VT驱动远程执行
    
    Args:
        进程PID: 目标进程PID
        执行数据: 执行数据缓冲区 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
        数据大小: 执行数据大小（可选）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    
    Note:
        需要调用HCHD_LoadDrv2传递参数2来安装HDVT驱动
    """
    hd = Config.get_hd()
    
    HCHDVT_RemoteCall = hd.HCHDVT_RemoteCall
    HCHDVT_RemoteCall.restype = ctypes.c_int64
    HCHDVT_RemoteCall.argtypes = [ctypes.c_int32, ctypes.c_void_p, ctypes.c_int32]
    
    if 数据大小 is None:
        数据大小 = len(执行数据)
    
    ret = HCHDVT_RemoteCall(ctypes.c_int32(进程PID), 执行数据, ctypes.c_int32(数据大小))
    return ret

# INT64 __stdcall HCHDVT_InjectDllX64(int pid, void* dllData, int size);
def HDVT_DLL无痕注入X64(进程PID: int, DLL数据: bytes, 数据大小: int = None) -> int:
    """
    VT驱动DLL无痕注入X64
    
    Args:
        进程PID: 目标进程PID
        DLL数据: DLL数据缓冲区 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
        数据大小: DLL数据大小（可选）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    
    Note:
        需要调用HCHD_LoadDrv2传递参数2来安装HDVT驱动
    """
    hd = Config.get_hd()
    
    HCHDVT_InjectDllX64 = hd.HCHDVT_InjectDllX64
    HCHDVT_InjectDllX64.restype = ctypes.c_int64
    HCHDVT_InjectDllX64.argtypes = [ctypes.c_int32, ctypes.c_void_p, ctypes.c_int32]
    
    if 数据大小 is None:
        数据大小 = len(DLL数据)
    
    ret = HCHDVT_InjectDllX64(ctypes.c_int32(进程PID), DLL数据, ctypes.c_int32(数据大小))
    return ret

# INT64 __stdcall HCHDVT_InjectDllX86(int pid, void* dllData, int size);
def HDVT_DLL无痕注入X86(进程PID: int, DLL数据: bytes, 数据大小: int = None) -> int:
    """
    VT驱动DLL无痕注入X86
    
    Args:
        进程PID: 目标进程PID
        DLL数据: DLL数据缓冲区 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
        数据大小: DLL数据大小（可选）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    
    Note:
        需要调用HCHD_LoadDrv2传递参数2来安装HDVT驱动
    """
    hd = Config.get_hd()
    
    HCHDVT_InjectDllX86 = hd.HCHDVT_InjectDllX86
    HCHDVT_InjectDllX86.restype = ctypes.c_int64
    HCHDVT_InjectDllX86.argtypes = [ctypes.c_int32, ctypes.c_void_p, ctypes.c_int32]
    
    if 数据大小 is None:
        数据大小 = len(DLL数据)
    
    ret = HCHDVT_InjectDllX86(ctypes.c_int32(进程PID), DLL数据, ctypes.c_int32(数据大小))
    return ret

# INT64 __stdcall HCHDVT_InstallPlugX64(int pid);
def HDVT_安装插件X64(进程PID: int) -> int:
    """
    VT驱动安装插件X64
    
    Args:
        进程PID: 目标进程PID
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    
    Note:
        需要调用HCHD_LoadDrv2传递参数2来安装HDVT驱动
    """
    hd = Config.get_hd()
    
    HCHDVT_InstallPlugX64 = hd.HCHDVT_InstallPlugX64
    HCHDVT_InstallPlugX64.restype = ctypes.c_int64
    HCHDVT_InstallPlugX64.argtypes = [ctypes.c_int32]
    
    ret = HCHDVT_InstallPlugX64(ctypes.c_int32(进程PID))
    return ret

# INT64 __stdcall HCHDVT_InstallPlugX86(int pid);
def HDVT_安装插件X86(进程PID: int) -> int:
    """
    VT驱动安装插件X86
    
    Args:
        进程PID: 目标进程PID
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    
    Note:
        需要调用HCHD_LoadDrv2传递参数2来安装HDVT驱动
    """
    hd = Config.get_hd()
    
    HCHDVT_InstallPlugX86 = hd.HCHDVT_InstallPlugX86
    HCHDVT_InstallPlugX86.restype = ctypes.c_int64
    HCHDVT_InstallPlugX86.argtypes = [ctypes.c_int32]
    
    ret = HCHDVT_InstallPlugX86(ctypes.c_int32(进程PID))
    return ret






from .config import Config, ctypes
from .config import auto_encode

# INT64 __stdcall HCGB_Attach1(int winIndex);
def HD内置浏览器_附加谷歌1(窗口序号: int) -> int:
    """
    附加内置浏览器（附加监听模式1）
    
    Args:
        窗口序号: 窗口序号（从1开始）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCGB_Attach1 = hd.HCGB_Attach1
    HCGB_Attach1.restype = ctypes.c_int64
    HCGB_Attach1.argtypes = [ctypes.c_int32]
    
    ret = HCGB_Attach1(ctypes.c_int32(窗口序号))
    return ret

# INT64 __stdcall HCGB_Attach2(int winIndex);
def HD内置浏览器_附加谷歌2(窗口序号: int) -> int:
    """
    附加内置浏览器（附加监听模式2）
    
    Args:
        窗口序号: 窗口序号（从1开始）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCGB_Attach2 = hd.HCGB_Attach2
    HCGB_Attach2.restype = ctypes.c_int64
    HCGB_Attach2.argtypes = [ctypes.c_int32]
    
    ret = HCGB_Attach2(ctypes.c_int32(窗口序号))
    return ret

# INT64 __stdcall HCGB_Detach(int winIndex);
def HD内置浏览器_脱离谷歌(窗口序号: int) -> int:
    """
    脱离之前的内置浏览器
    
    Args:
        窗口序号: 窗口序号（从1开始）
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCGB_Detach = hd.HCGB_Detach
    HCGB_Detach.restype = ctypes.c_int64
    HCGB_Detach.argtypes = [ctypes.c_int32]
    
    ret = HCGB_Detach(ctypes.c_int32(窗口序号))
    return ret

# INT64 __stdcall HCGB_InjectJSCode(int winIndex, char* codeBuffer, BOOL mainThread);
def HD内置浏览器_注入谷歌JS代码(窗口序号: int, JS代码: str, 是否主线程: bool = False) -> int:
    """
    给内置浏览器注入JS代码
    
    Args:
        窗口序号: 窗口序号（从1开始）
        JS代码: JS代码内容
        是否主线程: 是否在主线程执行，默认False
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCGB_InjectJSCode = hd.HCGB_InjectJSCode
    HCGB_InjectJSCode.restype = ctypes.c_int64
    HCGB_InjectJSCode.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_bool]
    
    ret = HCGB_InjectJSCode(
        ctypes.c_int32(窗口序号),
        auto_encode(JS代码),
        ctypes.c_bool(是否主线程)
    )
    return ret

# INT64 __stdcall HCGB_ExcuteJSFile(int winIndex, char* fileName, BOOL mainThread);
def HD内置浏览器_注入谷歌JS文件(窗口序号: int, JS文件路径: str, 是否主线程: bool = False) -> int:
    """
    给内置浏览器注入指定文件中的JS代码
    
    Args:
        窗口序号: 窗口序号（从1开始）
        JS文件路径: JS文件的完整路径
        是否主线程: 是否在主线程执行，默认False
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCGB_ExcuteJSFile = hd.HCGB_ExcuteJSFile
    HCGB_ExcuteJSFile.restype = ctypes.c_int64
    HCGB_ExcuteJSFile.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_bool]
    
    ret = HCGB_ExcuteJSFile(
        ctypes.c_int32(窗口序号),
        auto_encode(JS文件路径),
        ctypes.c_bool(是否主线程)
    )
    return ret


from .config import Config, ctypes
from .config import auto_encode

# INT64 __stdcall HCWIN_SortWindows(int offsetW, int offsetH, int width, int height);
def HD窗口_排序通讯窗口(水平偏移: int, 垂直偏移: int, 宽度: int, 高度: int) -> int:
    """
    排序安装过插件的进程
    
    Args:
        水平偏移: 水平偏移距离（2个相邻窗口的左上角的水平距离）
        垂直偏移: 垂直偏移距离（2个相邻窗口的左上角的垂直距离）
        宽度: 窗口宽度
        高度: 窗口高度
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    
    Note:
        安装过插件的进程一般表现为：
        1. 通讯过的窗口序号对应的进程PID（未被第二次初始化序号HCInject_Init）
        2. 卸载进程环境不会影响绑定过的进程排序（不能调用初始化序号HCInject_Init的前提下，也就是可以重连的情况下）
        3. HCInject_Init接口一旦调用，会取消所有关联（意味着不能重连），从而影响当前绑定的窗口PID，意味着新窗口即将打开
    """
    hd = Config.get_hd()
    
    HCWIN_SortWindows = hd.HCWIN_SortWindows
    HCWIN_SortWindows.restype = ctypes.c_int64
    HCWIN_SortWindows.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32]
    
    ret = HCWIN_SortWindows(
        ctypes.c_int32(水平偏移),
        ctypes.c_int32(垂直偏移),
        ctypes.c_int32(宽度),
        ctypes.c_int32(高度)
    )
    return ret

# INT64 __stdcall HCWIN_CamouflageProcess(char* runName, char* targetPath, int type);
def HD窗口_伪装进程(运行名称: str, 目标路径: str, 进程位数: int) -> int:
    """
    伪装进程（防止检查到实际的进程存在）
    
    Args:
        运行名称: 给伪装进程取的别名（任意前缀/后缀名字），如：hd.dat
        目标路径: 需要伪装的进程全路径（包含.exe），如：c:\\game.exe
        进程位数: 需要伪装的进程位数，32或64
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_CamouflageProcess = hd.HCWIN_CamouflageProcess
    HCWIN_CamouflageProcess.restype = ctypes.c_int64
    HCWIN_CamouflageProcess.argtypes = [ctypes.c_char_p, ctypes.c_char_p, ctypes.c_int32]
    
    ret = HCWIN_CamouflageProcess(
        auto_encode(运行名称),
        auto_encode(目标路径),
        ctypes.c_int32(进程位数)
    )
    return ret

# INT64 __stdcall HCWIN_SetWindowState(INT64 hwnd, int type);
def HD窗口_设置窗口状态(窗口句柄: int, 状态类型: int) -> int:
    """
    设置或者操作窗口状态
    
    Args:
        窗口句柄: 窗口句柄，如果状态类型==18/19表示刷新桌面，这个时候窗口句柄可以为0
        状态类型: 窗口状态类型（1-19），-1/0表示不指定
            激活指定窗口(1) 显示最小化窗口,并不激活(2) 显示最小化窗口,同时激活窗口(3) 显示最大化窗口,同时激活窗口(4)
            显示窗口,但是不激活(5) 隐藏窗口(6) 显示窗口,并激活(7) 置顶窗口(8) 取消置顶窗口(9) 禁止窗口(10) 取消禁止窗口(11)
            恢复并激活窗口(12) 强制结束窗口所在的进程(13) 闪烁窗口(14) 窗口获取输入焦点(15) 发消息关闭指定窗口,不是强制关闭(16)
            强制刷新指定窗口(17) 强制刷新桌面窗口(18) 强制刷新桌面窗口+任务栏(19)
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_SetWindowState = hd.HCWIN_SetWindowState
    HCWIN_SetWindowState.restype = ctypes.c_int64
    HCWIN_SetWindowState.argtypes = [ctypes.c_int64, ctypes.c_int32]
    
    ret = HCWIN_SetWindowState(
        ctypes.c_int64(窗口句柄),
        ctypes.c_int32(状态类型)
    )
    return ret

# INT64 __stdcall HCWIN_SetWindowSize(INT64 hwnd, int width, int height, BOOL bCenter);
def HD窗口_设置窗口大小(窗口句柄: int, 宽度: int, 高度: int, 是否居中: bool = False) -> int:
    """
    设置窗口大小
    
    Args:
        窗口句柄: 窗口句柄
        宽度: 窗口宽度
        高度: 窗口高度
        是否居中: 窗口是否居中，默认False
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_SetWindowSize = hd.HCWIN_SetWindowSize
    HCWIN_SetWindowSize.restype = ctypes.c_int64
    HCWIN_SetWindowSize.argtypes = [ctypes.c_int64, ctypes.c_int32, ctypes.c_int32, ctypes.c_bool]
    
    ret = HCWIN_SetWindowSize(
        ctypes.c_int64(窗口句柄),
        ctypes.c_int32(宽度),
        ctypes.c_int32(高度),
        ctypes.c_bool(是否居中)
    )
    return ret

# INT64 __stdcall HCWIN_MoveWindow(INT64 hwnd, int x, int y);
def HD窗口_窗口移动(窗口句柄: int, X坐标: int, Y坐标: int) -> int:
    """
    移动窗口
    
    Args:
        窗口句柄: 窗口句柄
        X坐标: 窗口x坐标
        Y坐标: 窗口y坐标
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_MoveWindow = hd.HCWIN_MoveWindow
    HCWIN_MoveWindow.restype = ctypes.c_int64
    HCWIN_MoveWindow.argtypes = [ctypes.c_int64, ctypes.c_int32, ctypes.c_int32]
    
    ret = HCWIN_MoveWindow(
        ctypes.c_int64(窗口句柄),
        ctypes.c_int32(X坐标),
        ctypes.c_int32(Y坐标)
    )
    return ret

# INT64 __stdcall HCWIN_IsWow64Process(INT64 hwnd, int pid);
def HD窗口_是否64位进程(窗口句柄: int, 进程ID: int = 0) -> int:
    """
    判断窗口是否是64位进程
    
    Args:
        窗口句柄: 窗口句柄
        进程ID: 进程id，默认0
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_IsWow64Process = hd.HCWIN_IsWow64Process
    HCWIN_IsWow64Process.restype = ctypes.c_int64
    HCWIN_IsWow64Process.argtypes = [ctypes.c_int64, ctypes.c_int32]
    
    ret = HCWIN_IsWow64Process(
        ctypes.c_int64(窗口句柄),
        ctypes.c_int32(进程ID)
    )
    return ret

# INT64 __stdcall HCWIN_GetWindowTitle(INT64 hwnd);
def HD窗口_获取窗口标题(窗口句柄: int) -> int:
    """
    获取窗口标题
    
    Args:
        窗口句柄: 窗口句柄
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_GetWindowTitle = hd.HCWIN_GetWindowTitle
    HCWIN_GetWindowTitle.restype = ctypes.c_int64
    HCWIN_GetWindowTitle.argtypes = [ctypes.c_int64]
    
    ret = HCWIN_GetWindowTitle(ctypes.c_int64(窗口句柄))
    return ret

# INT64 __stdcall HCWIN_GetWindowThreadProcessId(INT64 hwnd);
def HD窗口_获取窗口线程ID(窗口句柄: int) -> int:
    """
    获取目标窗口句柄的线程ID
    
    Args:
        窗口句柄: 窗口句柄
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_GetWindowThreadProcessId = hd.HCWIN_GetWindowThreadProcessId
    HCWIN_GetWindowThreadProcessId.restype = ctypes.c_int64
    HCWIN_GetWindowThreadProcessId.argtypes = [ctypes.c_int64]
    
    ret = HCWIN_GetWindowThreadProcessId(ctypes.c_int64(窗口句柄))
    return ret

# INT64 __stdcall HCWIN_GetWindowProcessId(INT64 hwnd);
def HD窗口_获取窗口进程ID(窗口句柄: int) -> int:
    """
    获取目标窗口句柄的进程ID
    
    Args:
        窗口句柄: 窗口句柄
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_GetWindowProcessId = hd.HCWIN_GetWindowProcessId
    HCWIN_GetWindowProcessId.restype = ctypes.c_int64
    HCWIN_GetWindowProcessId.argtypes = [ctypes.c_int64]
    
    ret = HCWIN_GetWindowProcessId(ctypes.c_int64(窗口句柄))
    return ret

# INT64 __stdcall HCWIN_GetWindowProcessPath(INT64 hwnd);
def HD窗口_获取窗口进程路径(窗口句柄: int) -> int:
    """
    获取目标窗口句柄的进程路径
    
    Args:
        窗口句柄: 窗口句柄
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_GetWindowProcessPath = hd.HCWIN_GetWindowProcessPath
    HCWIN_GetWindowProcessPath.restype = ctypes.c_int64
    HCWIN_GetWindowProcessPath.argtypes = [ctypes.c_int64]
    
    ret = HCWIN_GetWindowProcessPath(ctypes.c_int64(窗口句柄))
    return ret

# INT64 __stdcall HCWIN_GetWindowRect(INT64 hwnd, void* pRect);
def HD窗口_获取窗口位置(窗口句柄: int, 矩形指针=None) -> int:
    """
    获取窗口在屏幕上的位置
    
    Args:
        窗口句柄: 窗口句柄
        矩形指针: 指向RECT结构体地址（供C/C++调用，其他语言指定空），这个参数可以直接获取值，如果是其他语言可以HCEnv_GetRetJson获取字符串
    
    Returns:
        int: 返回值代码（查看HD返回值表），"left|top|right|bottom|"字符串从返回值json接口获取
    """
    hd = Config.get_hd()
    
    HCWIN_GetWindowRect = hd.HCWIN_GetWindowRect
    HCWIN_GetWindowRect.restype = ctypes.c_int64
    HCWIN_GetWindowRect.argtypes = [ctypes.c_int64, ctypes.c_void_p]
    
    ret = HCWIN_GetWindowRect(ctypes.c_int64(窗口句柄), 矩形指针)
    return ret

# INT64 __stdcall HCWIN_GetWindowClass(INT64 hwnd);
def HD窗口_获取窗口类名(窗口句柄: int) -> int:
    """
    获取目标窗口句柄的窗口类名
    
    Args:
        窗口句柄: 窗口句柄
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_GetWindowClass = hd.HCWIN_GetWindowClass
    HCWIN_GetWindowClass.restype = ctypes.c_int64
    HCWIN_GetWindowClass.argtypes = [ctypes.c_int64]
    
    ret = HCWIN_GetWindowClass(ctypes.c_int64(窗口句柄))
    return ret

# INT64 __stdcall HCWIN_GetWindowState(INT64 hwnd, int flag);
def HD窗口_获取窗口状态(窗口句柄: int, 状态标志: int) -> int:
    """
    获取目标窗口句柄的窗口状态
    
    Args:
        窗口句柄: 窗口句柄
        状态标志: 状态类型
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_GetWindowState = hd.HCWIN_GetWindowState
    HCWIN_GetWindowState.restype = ctypes.c_int64
    HCWIN_GetWindowState.argtypes = [ctypes.c_int64, ctypes.c_int32]
    
    ret = HCWIN_GetWindowState(
        ctypes.c_int64(窗口句柄),
        ctypes.c_int32(状态标志)
    )
    return ret

# INT64 __stdcall HCWIN_GetSpecialWindow(int flag);
def HD窗口_获取特殊窗口(特殊标志: int) -> int:
    """
    获取特殊窗口 桌面 Shell_TrayWnd
    
    Args:
        特殊标志: 桌面(0), Shell_TrayWnd(1)
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_GetSpecialWindow = hd.HCWIN_GetSpecialWindow
    HCWIN_GetSpecialWindow.restype = ctypes.c_int64
    HCWIN_GetSpecialWindow.argtypes = [ctypes.c_int32]
    
    ret = HCWIN_GetSpecialWindow(ctypes.c_int32(特殊标志))
    return ret

# INT64 __stdcall HCWIN_GetWindow(INT64 hwnd, int flag);
def HD窗口_获取窗口关联句柄(窗口句柄: int, 关联标志: int) -> int:
    """
    获取目标窗口句柄的关联窗口句柄
    
    Args:
        窗口句柄: 窗口句柄
        关联标志: 获取父窗口(0),获取第一个子窗口(1),获取第一个窗口(2),获取最后个窗口(3),获取下一个窗口(4),获取上一个窗口(5),获取拥有者窗口(6),获取顶层窗口(7)
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_GetWindow = hd.HCWIN_GetWindow
    HCWIN_GetWindow.restype = ctypes.c_int64
    HCWIN_GetWindow.argtypes = [ctypes.c_int64, ctypes.c_int32]
    
    ret = HCWIN_GetWindow(
        ctypes.c_int64(窗口句柄),
        ctypes.c_int32(关联标志)
    )
    return ret

# INT64 __stdcall HCWIN_GetMousePointWindow();
def HD窗口_获取鼠标指向窗口句柄() -> int:
    """
    获取鼠标指向窗口句柄
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_GetMousePointWindow = hd.HCWIN_GetMousePointWindow
    HCWIN_GetMousePointWindow.restype = ctypes.c_int64
    HCWIN_GetMousePointWindow.argtypes = []
    
    ret = HCWIN_GetMousePointWindow()
    return ret

# INT64 __stdcall HCWIN_GetPointWindow(int x, int y);
def HD窗口_获取指向窗口句柄(X坐标: int, Y坐标: int) -> int:
    """
    获取指定坐标的窗口句柄
    
    Args:
        X坐标: x坐标
        Y坐标: y坐标
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_GetPointWindow = hd.HCWIN_GetPointWindow
    HCWIN_GetPointWindow.restype = ctypes.c_int64
    HCWIN_GetPointWindow.argtypes = [ctypes.c_int32, ctypes.c_int32]
    
    ret = HCWIN_GetPointWindow(
        ctypes.c_int32(X坐标),
        ctypes.c_int32(Y坐标)
    )
    return ret

# INT64 __stdcall HCWIN_GetForegroundWindow();
def HD窗口_获取顶层活动窗口句柄() -> int:
    """
    获取顶层活动窗口，可以获取到按键自带插件无法获取到的句柄
    
    Returns:
        int: 返回值代码（查看HD返回值表）或者句柄
    """
    hd = Config.get_hd()
    
    HCWIN_GetForegroundWindow = hd.HCWIN_GetForegroundWindow
    HCWIN_GetForegroundWindow.restype = ctypes.c_int64
    HCWIN_GetForegroundWindow.argtypes = []
    
    ret = HCWIN_GetForegroundWindow()
    return ret

# INT64 __stdcall HCWIN_GetForegroundFocus();
def HD窗口_获取顶层焦点窗口句柄() -> int:
    """
    获取顶层活动窗口中具有输入焦点的窗口句柄
    
    Returns:
        int: 返回值代码（查看HD返回值表）或者句柄
    """
    hd = Config.get_hd()
    
    HCWIN_GetForegroundFocus = hd.HCWIN_GetForegroundFocus
    HCWIN_GetForegroundFocus.restype = ctypes.c_int64
    HCWIN_GetForegroundFocus.argtypes = []
    
    ret = HCWIN_GetForegroundFocus()
    return ret

# INT64 __stdcall HCWIN_SetForegroundFocus(INT64 hwnd);
def HD窗口_设置焦点到窗口(窗口句柄: int) -> int:
    """
    设置输入焦点到窗口
    
    Args:
        窗口句柄: 窗口句柄
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_SetForegroundFocus = hd.HCWIN_SetForegroundFocus
    HCWIN_SetForegroundFocus.restype = ctypes.c_int64
    HCWIN_SetForegroundFocus.argtypes = [ctypes.c_int64]
    
    ret = HCWIN_SetForegroundFocus(ctypes.c_int64(窗口句柄))
    return ret

# INT64 __stdcall HCWIN_GetClientSize(INT64 hwnd, void* pW, void* pH);
def HD窗口_获取窗口客户区域(窗口句柄: int, 宽度指针=None, 高度指针=None) -> int:
    """
    获取窗口客户区域的宽度和高度
    
    Args:
        窗口句柄: 窗口句柄
        宽度指针: 调用HD通用_获取最近返回Json获取字符串并自行解析
        高度指针: 调用HD通用_获取最近返回Json获取字符串并自行解析
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_GetClientSize = hd.HCWIN_GetClientSize
    HCWIN_GetClientSize.restype = ctypes.c_int64
    HCWIN_GetClientSize.argtypes = [ctypes.c_int64, ctypes.c_void_p, ctypes.c_void_p]
    
    ret = HCWIN_GetClientSize(
        ctypes.c_int64(窗口句柄),
        宽度指针,
        高度指针
    )
    return ret

# INT64 __stdcall HCWIN_GetClientRectInWindow(INT64 hwnd, void* pRect);
def HD窗口_获取窗口客户区域在屏幕(窗口句柄: int, 矩形指针=None) -> int:
    """
    获取窗口客户区域在屏幕上的位置
    
    Args:
        窗口句柄: 窗口句柄
        矩形指针: 调用HD通用_获取最近返回Json获取字符串并自行解析
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_GetClientRectInWindow = hd.HCWIN_GetClientRectInWindow
    HCWIN_GetClientRectInWindow.restype = ctypes.c_int64
    HCWIN_GetClientRectInWindow.argtypes = [ctypes.c_int64, ctypes.c_void_p]
    
    ret = HCWIN_GetClientRectInWindow(
        ctypes.c_int64(窗口句柄),
        矩形指针
    )
    return ret

# INT64 __stdcall HCWIN_FindWindowEx(INT64 parentHwnd, char* className, char* title, BOOL bType);
def HD窗口_查找窗口(父窗口句柄: int, 类名: str = None, 标题: str = None, 是否模糊: bool = True) -> int:
    """
    查找符合类名或者标题名的顶层可见窗口，如果指定了parent，则在parent的第一层子窗口中查找
    
    Args:
        父窗口句柄: 窗口的父窗口句柄（不指定则从桌面窗口开始搜索）
        类名: 窗口类名（不指定为None）
        标题: 窗口标题（不指定为None）
        是否模糊: True为模糊匹配，False为完全匹配
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_FindWindowEx = hd.HCWIN_FindWindowEx
    HCWIN_FindWindowEx.restype = ctypes.c_int64
    HCWIN_FindWindowEx.argtypes = [ctypes.c_int64, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_bool]
    
    类名字节 = auto_encode(类名) if 类名 else None
    标题字节 = auto_encode(标题) if 标题 else None
    
    ret = HCWIN_FindWindowEx(
        ctypes.c_int64(父窗口句柄),
        类名字节,
        标题字节,
        ctypes.c_bool(是否模糊)
    )
    return ret

# INT64 __stdcall HCWIN_FindTopWindow(char* className, char* title, BOOL bType);
def HD窗口_查找顶层窗口(类名: str = None, 标题: str = None, 是否模糊: bool = True) -> int:
    """
    查找顶层窗口句柄，父窗口句柄为NULL
    
    Args:
        类名: 窗口类名（不指定为None）
        标题: 窗口标题（不指定为None）
        是否模糊: True为模糊匹配，False为完全匹配
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_FindTopWindow = hd.HCWIN_FindTopWindow
    HCWIN_FindTopWindow.restype = ctypes.c_int64
    HCWIN_FindTopWindow.argtypes = [ctypes.c_char_p, ctypes.c_char_p, ctypes.c_bool]
    
    类名字节 = auto_encode(类名) if 类名 else None
    标题字节 = auto_encode(标题) if 标题 else None
    
    ret = HCWIN_FindTopWindow(
        类名字节,
        标题字节,
        ctypes.c_bool(是否模糊)
    )
    return ret

# INT64 __stdcall HCWIN_EnumWindowByProcess(char* processName, char* className, char* title, int filter, BOOL bType);
def HD窗口_枚举查找窗口(进程名: str, 类名: str, 标题: str, 过滤器: int, 是否模糊: bool) -> int:
    """
    根据指定进程以及其它条件，枚举系统中符合条件的窗口
    
    Args:
        进程名: 进程名（如果是完全匹配要加.exe，如果是模糊匹配自行判断）
        类名: 窗口类名（不指定为None）
        标题: 窗口标题（不指定为None）
        过滤器: 1标题 2类名 4第一个PID 8检测是否有父窗口 16检查窗口句柄是否有效 32检索多PID 多个标识可以用|累加
        是否模糊: True为模糊匹配，False为完全匹配
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_EnumWindowByProcess = hd.HCWIN_EnumWindowByProcess
    HCWIN_EnumWindowByProcess.restype = ctypes.c_int64
    HCWIN_EnumWindowByProcess.argtypes = [ctypes.c_char_p, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_int32, ctypes.c_bool]
    
    ret = HCWIN_EnumWindowByProcess(
        auto_encode(进程名),
        auto_encode(类名),
        auto_encode(标题),
        ctypes.c_int32(过滤器),
        ctypes.c_bool(是否模糊)
    )
    return ret

# INT64 __stdcall HCWIN_EnumWindowByProcessId(int pid, char* className, char* title, int filter, BOOL bType);
def HD窗口_枚举查找窗口Ex(进程ID: int, 类名: str, 标题: str, 过滤器: int, 是否模糊: bool) -> int:
    """
    根据指定进程以及其它条件，枚举系统中符合条件的窗口
    
    Args:
        进程ID: 进程ID
        类名: 窗口类名（不指定为None）
        标题: 窗口标题（不指定为None）
        过滤器: 标题 2类名 8检测是否有父窗口（也就是是否是顶级窗口）16检查窗口句柄是否有效 多个标识可以用|累加
        是否模糊: True为模糊匹配，False为完全匹配
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_EnumWindowByProcessId = hd.HCWIN_EnumWindowByProcessId
    HCWIN_EnumWindowByProcessId.restype = ctypes.c_int64
    HCWIN_EnumWindowByProcessId.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_int32, ctypes.c_bool]
    
    ret = HCWIN_EnumWindowByProcessId(
        ctypes.c_int32(进程ID),
        auto_encode(类名),
        auto_encode(标题),
        ctypes.c_int32(过滤器),
        ctypes.c_bool(是否模糊)
    )
    return ret

# INT64 __stdcall HCWIN_EnumProcess(char* processName, BOOL bType);
def HD窗口_枚举进程(进程名: str, 是否模糊: bool) -> int:
    """
    根据指定进程名，枚举系统中符合条件的进程PID
    
    Args:
        进程名: 进程名（如果是完全匹配要加.exe，如果是模糊匹配自行判断）
        是否模糊: True为模糊匹配，False为完全匹配
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_EnumProcess = hd.HCWIN_EnumProcess
    HCWIN_EnumProcess.restype = ctypes.c_int64
    HCWIN_EnumProcess.argtypes = [ctypes.c_char_p, ctypes.c_bool]
    
    ret = HCWIN_EnumProcess(
        auto_encode(进程名),
        ctypes.c_bool(是否模糊)
    )
    return ret

# INT64 __stdcall HCWIN_EnumWindow(INT64 parentHwnd, char* className, char* title, int filter, BOOL bType);
def HD窗口_枚举窗口(父窗口句柄: int, 类名: str, 标题: str, 过滤器: int, 是否模糊: bool, 是否子窗口: bool = False) -> int:
    """
    根据指定条件，枚举系统中符合条件的窗口，可以枚举到按键自带的无法枚举到的窗口
    
    Args:
        父窗口句柄: 父窗口句柄（0为顶层窗口）
        类名: 窗口类名（不指定为None）
        标题: 窗口标题（不指定为None）
        过滤器: 标题 2类名 8检测是否有父窗口（也就是是否是顶级窗口）16检查窗口句柄是否有效 多个标识可以用|累加
        是否模糊: True为模糊匹配，False为完全匹配
        是否子窗口: True为枚举子窗口，False为枚举顶级窗口
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCWIN_EnumWindow = hd.HCWIN_EnumWindow
    HCWIN_EnumWindow.restype = ctypes.c_int64
    HCWIN_EnumWindow.argtypes = [ctypes.c_int64, ctypes.c_char_p, ctypes.c_char_p, ctypes.c_int32, ctypes.c_bool, ctypes.c_bool]
    
    ret = HCWIN_EnumWindow(
        ctypes.c_int64(父窗口句柄),
        auto_encode(类名),
        auto_encode(标题),
        ctypes.c_int32(过滤器),
        ctypes.c_bool(是否模糊),
        ctypes.c_bool(是否子窗口)
    )
    return ret